@@ -15,7 +15,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 """
     TS Sphinx Directives
     ~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -45,6 +44,7 @@ try:
     def is_string_type(s):
         return isinstance(s, basestring)
 except NameError:
+
     def is_string_type(s):
         return isinstance(s, str)
 
@@ -161,6 +161,7 @@ class TSConfVar(std.Target):
 
 
 class TSConfVarRef(XRefRole):
+
     def process_link(self, env, ref_node, explicit_title_p, title, target):
         return title, target
 
@@ -171,18 +172,9 @@ def metrictypes(typename):
 
 def metricunits(unitname):
     return directives.choice(
-        unitname.lower(),
-        ('ratio',
-         'percent',
-         'kbits',
-         'mbits',
-         'bytes',
-         'kbytes',
-         'mbytes',
-         'nanoseconds',
-         'microseconds',
-         'milliseconds',
-         'seconds'))
+        unitname.lower(), (
+            'ratio', 'percent', 'kbits', 'mbits', 'bytes', 'kbytes', 'mbytes', 'nanoseconds', 'microseconds', 'milliseconds',
+            'seconds'))
 
 
 class TSStat(std.Target):
@@ -301,6 +293,7 @@ class TSStat(std.Target):
 
 
 class TSStatRef(XRefRole):
+
     def process_link(self, env, ref_node, explicit_title_p, title, target):
         return title, target
 
@@ -319,15 +312,9 @@ class TrafficServerDomain(Domain):
         'stat': ObjType(_('statistic'), 'stat')
     }
 
-    directives = {
-        'cv': TSConfVar,
-        'stat': TSStat
-    }
+    directives = {'cv': TSConfVar, 'stat': TSStat}
 
-    roles = {
-        'cv': TSConfVarRef(),
-        'stat': TSStatRef()
-    }
+    roles = {'cv': TSConfVarRef(), 'stat': TSStatRef()}
 
     initial_data = {
         'cv': {},  # full name -> docname
@@ -380,6 +367,7 @@ class TrafficServerDomain(Domain):
             for var, doc in self.data['stat'].iteritems():
                 yield var, var, 'stat', doc, var, 1
     except AttributeError:
+
         def get_objects(self):
             for var, doc in self.data['cv'].items():
                 yield var, var, 'cv', doc, var, 1
@@ -388,8 +376,7 @@ class TrafficServerDomain(Domain):
 
 
 # get the branch this documentation is building for in X.X.x form
-REPO_ROOT = os.path.join(os.path.dirname(os.path.dirname(
-    os.environ['DOCUTILSCONFIG'])))
+REPO_ROOT = os.path.join(os.path.dirname(os.path.dirname(os.environ['DOCUTILSCONFIG'])))
 CONFIGURE_AC = os.path.join(REPO_ROOT, 'configure.ac')
 with open(CONFIGURE_AC, 'r') as f:
     contents = f.read()
@@ -398,8 +385,7 @@ with open(CONFIGURE_AC, 'r') as f:
 
 # get the current branch the local repository is on
 REPO_GIT_DIR = os.path.join(REPO_ROOT, ".git")
-git_branch = subprocess.check_output(['git', '--git-dir', REPO_GIT_DIR,
-                                      'rev-parse', '--abbrev-ref', 'HEAD'])
+git_branch = subprocess.check_output(['git', '--git-dir', REPO_GIT_DIR, 'rev-parse', '--abbrev-ref', 'HEAD'])
 
 
 def make_github_link(name, rawtext, text, lineno, inliner, options=None, content=None):
@@ -429,9 +415,7 @@ def make_github_link(name, rawtext, text, lineno, inliner, options=None, content
 
 
 def setup(app):
-    app.add_crossref_type('configfile', 'file',
-                          objname='Configuration file',
-                          indextemplate='pair: %s; Configuration files')
+    app.add_crossref_type('configfile', 'file', objname='Configuration file', indextemplate='pair: %s; Configuration files')
 
     # Very ugly, but as of Sphinx 1.8 it must be done. There is an `override` option to add_crossref_type
     # but it only applies to the directive, not the role (`file` in this case). If this isn't cleared
@@ -440,9 +424,7 @@ def setup(app):
     # names are disjoint sets.
     del app.registry.domain_roles['std']['file']
 
-    app.add_crossref_type('logfile', 'file',
-                          objname='Log file',
-                          indextemplate='pair: %s; Log files')
+    app.add_crossref_type('logfile', 'file', objname='Log file', indextemplate='pair: %s; Log files')
 
     rst.roles.register_generic_role('arg', nodes.emphasis)
     rst.roles.register_generic_role('const', nodes.literal)
