@@ -73,13 +73,18 @@ int64_t TSCacheHttpInfoSizeGet(TSCacheHttpInfo infop);
 tsapi int TSMimeHdrFieldEqual(TSMBuffer bufp, TSMLoc hdr_obj, TSMLoc field1, TSMLoc field2);
 tsapi TSReturnCode TSHttpTxnHookRegisteredFor(TSHttpTxn txnp, TSHttpHookID id, TSEventFunc funcp);
 
+#if TS_VERSION_MAJOR < 10
+
+/* These are kept in the 9.x releases to preserve the ABI. These should be
+ * removed in the ATS 10 release. */
+
 /* Various HTTP "control" modes */
 typedef enum {
   TS_HTTP_CNTL_GET_LOGGING_MODE,
   TS_HTTP_CNTL_SET_LOGGING_MODE,
   TS_HTTP_CNTL_GET_INTERCEPT_RETRY_MODE,
   TS_HTTP_CNTL_SET_INTERCEPT_RETRY_MODE
-} TSHttpCntlType;
+} TSHttpCntlTypeExperimental;
 
 #define TS_HTTP_CNTL_OFF (void *)0
 #define TS_HTTP_CNTL_ON (void *)1
@@ -88,8 +93,9 @@ typedef enum {
    TSHttpTxnCntl(.., TS_HTTP_CNTL_GET_LOGGING_MODE, &onoff);
    if (onoff == TS_HTTP_CNTL_ON) ....
 */
-tsapi TSReturnCode TSHttpTxnCntl(TSHttpTxn txnp, TSHttpCntlType cntl, void *data);
+tsapi TSReturnCode TSHttpTxnCntl(TSHttpTxn txnp, TSHttpCntlTypeExperimental cntl, void *data);
 
+#endif
 /* Protocols APIs */
 tsapi void TSVConnCacheHttpInfoSet(TSVConn connp, TSCacheHttpInfo infop);
 
