@@ -25,6 +25,8 @@
 
 #include "tscore/ink_atomic.h"
 
+#include <cstddef>
+
 ////////////////////////////////////////////////////////////////////
 ////////////////////////////////////////////////////////////////////
 //////              ATOMIC VERSIONS
@@ -99,10 +101,12 @@ template <class T> class Ptr
 public:
   explicit Ptr(T *p = nullptr);
   Ptr(const Ptr<T> &);
+  Ptr(Ptr<T> &&);
   ~Ptr();
 
   void clear();
   Ptr<T> &operator=(const Ptr<T> &);
+  Ptr<T> &operator=(Ptr<T> &&);
   Ptr<T> &operator=(T *);
 
   T *
@@ -179,8 +183,6 @@ public:
 
 private:
   T *m_ptr;
-
-  friend class CoreUtils;
 };
 
 template <typename T>
@@ -209,6 +211,11 @@ template <class T> inline Ptr<T>::Ptr(const Ptr<T> &src) : m_ptr(src.m_ptr)
   }
 }
 
+template <class T> inline Ptr<T>::Ptr(Ptr<T> &&src) : m_ptr(src.m_ptr)
+{
+  src.m_ptr = nullptr;
+}
+
 template <class T> inline Ptr<T>::~Ptr()
 {
   if (m_ptr && m_ptr->refcount_dec() == 0) {
@@ -257,6 +264,18 @@ Ptr<T>::operator=(const Ptr<T> &src)
   return (operator=(src.m_ptr));
 }
 
+template <class T>
+inline Ptr<T> &
+Ptr<T>::operator=(Ptr<T> &&src)
+{
+  if (this != &src) {
+    this->~Ptr();
+    m_ptr     = src.m_ptr;
+    src.m_ptr = nullptr;
+  }
+  return *this;
+}
+
 // Bit of subtly here for the flipped version of equality checks
 // With only the template versions, the compiler will try to substitute @c nullptr_t
 // for @c T and fail, because that's not the type and no operator will be found.
