@@ -24,19 +24,15 @@
 #pragma once
 
 #include "tscore/ink_config.h"
+
 #include <stddef.h> // NOLINT(modernize-deprecated-headers)
-#include <sys/mman.h>
 
 #ifdef HAVE_STDINT_H
 #include <stdint.h> // NOLINT(modernize-deprecated-headers)
-#else
-// TODO: Add "standard" int types?
 #endif
 
 #ifdef HAVE_INTTYPES_H
 #include <inttypes.h> // NOLINT(modernize-deprecated-headers)
-#else
-// TODO: add PRI*64 stuff?
 #endif
 
 #ifndef INT64_MIN
@@ -61,11 +57,6 @@
 #endif
 #endif
 
-#if defined(darwin)
-#define RENTRENT_GETHOSTBYNAME
-#define RENTRENT_GETHOSTBYADDR
-#endif
-
 #define NUL '\0'
 
 // Determine the element count for an array.
@@ -100,33 +91,26 @@ countof(const T (&)[N])
 #define unlikely(x) __builtin_expect(!!(x), 0)
 #endif
 
-#if TS_USE_HWLOC
-#include <hwloc.h>
-#endif
-
-#ifndef ROUNDUP
-#define ROUNDUP(x, y) ((((x) + ((y)-1)) / (y)) * (y))
-#endif
-
-#if defined(MAP_NORESERVE)
-#define MAP_SHARED_MAP_NORESERVE (MAP_SHARED | MAP_NORESERVE)
-#else
-#define MAP_SHARED_MAP_NORESERVE (MAP_SHARED)
-#endif
-
 /* Variables
  */
-extern int debug_level;
 extern int off;
 extern int on;
 
 /* Functions
  */
-int ink_sys_name_release(char *name, int namelen, char *release, int releaselen);
-int ink_number_of_processors();
 int ink_login_name_max();
 
-#if TS_USE_HWLOC
-// Get the hardware topology
-hwloc_topology_t ink_get_topology();
+#ifdef __cplusplus
+// Round up a value to be a multiple of m if necessary.
+//
+template <typename ArithmeticV, typename ArithmeticM>
+constexpr ArithmeticV
+ROUNDUP(ArithmeticV value, ArithmeticM m)
+{
+  ArithmeticV remainder = value % m;
+  if (remainder) {
+    value += m - remainder;
+  }
+  return value;
+}
 #endif
