@@ -32,14 +32,19 @@
 
 #include "I_EThread.h"
 #include "I_EventProcessor.h"
+#include <execinfo.h>
 
 const ink_hrtime DELAY_FOR_RETRY = HRTIME_MSECONDS(10);
-extern ink_thread_key ethread_key;
 
 TS_INLINE Event *
 EThread::schedule_imm(Continuation *cont, int callback_event, void *cookie)
 {
-  Event *e          = ::eventAllocator.alloc();
+  Event *e = ::eventAllocator.alloc();
+
+#ifdef ENABLE_EVENT_TRACKER
+  e->set_location();
+#endif
+
   e->callback_event = callback_event;
   e->cookie         = cookie;
   return schedule(e->init(cont, 0, 0));
@@ -48,7 +53,12 @@ EThread::schedule_imm(Continuation *cont, int callback_event, void *cookie)
 TS_INLINE Event *
 EThread::schedule_at(Continuation *cont, ink_hrtime t, int callback_event, void *cookie)
 {
-  Event *e          = ::eventAllocator.alloc();
+  Event *e = ::eventAllocator.alloc();
+
+#ifdef ENABLE_EVENT_TRACKER
+  e->set_location();
+#endif
+
   e->callback_event = callback_event;
   e->cookie         = cookie;
   return schedule(e->init(cont, t, 0));
@@ -57,22 +67,32 @@ EThread::schedule_at(Continuation *cont, ink_hrtime t, int callback_event, void
 TS_INLINE Event *
 EThread::schedule_in(Continuation *cont, ink_hrtime t, int callback_event, void *cookie)
 {
-  Event *e          = ::eventAllocator.alloc();
+  Event *e = ::eventAllocator.alloc();
+
+#ifdef ENABLE_EVENT_TRACKER
+  e->set_location();
+#endif
+
   e->callback_event = callback_event;
   e->cookie         = cookie;
-  return schedule(e->init(cont, get_hrtime() + t, 0));
+  return schedule(e->init(cont, ink_get_hrtime() + t, 0));
 }
 
 TS_INLINE Event *
 EThread::schedule_every(Continuation *cont, ink_hrtime t, int callback_event, void *cookie)
 {
-  Event *e          = ::eventAllocator.alloc();
+  Event *e = ::eventAllocator.alloc();
+
+#ifdef ENABLE_EVENT_TRACKER
+  e->set_location();
+#endif
+
   e->callback_event = callback_event;
   e->cookie         = cookie;
   if (t < 0) {
     return schedule(e->init(cont, t, t));
   } else {
-    return schedule(e->init(cont, get_hrtime() + t, t));
+    return schedule(e->init(cont, ink_get_hrtime() + t, t));
   }
 }
 
@@ -108,7 +128,12 @@ EThread::schedule(Event *e)
 TS_INLINE Event *
 EThread::schedule_imm_local(Continuation *cont, int callback_event, void *cookie)
 {
-  Event *e          = EVENT_ALLOC(eventAllocator, this);
+  Event *e = EVENT_ALLOC(eventAllocator, this);
+
+#ifdef ENABLE_EVENT_TRACKER
+  e->set_location();
+#endif
+
   e->callback_event = callback_event;
   e->cookie         = cookie;
   return schedule_local(e->init(cont, 0, 0));
@@ -117,7 +142,12 @@ EThread::schedule_imm_local(Continuation *cont, int callback_event, void *cookie
 TS_INLINE Event *
 EThread::schedule_at_local(Continuation *cont, ink_hrtime t, int callback_event, void *cookie)
 {
-  Event *e          = EVENT_ALLOC(eventAllocator, this);
+  Event *e = EVENT_ALLOC(eventAllocator, this);
+
+#ifdef ENABLE_EVENT_TRACKER
+  e->set_location();
+#endif
+
   e->callback_event = callback_event;
   e->cookie         = cookie;
   return schedule_local(e->init(cont, t, 0));
@@ -126,22 +156,32 @@ EThread::schedule_at_local(Continuation *cont, ink_hrtime t, int callback_event,
 TS_INLINE Event *
 EThread::schedule_in_local(Continuation *cont, ink_hrtime t, int callback_event, void *cookie)
 {
-  Event *e          = EVENT_ALLOC(eventAllocator, this);
+  Event *e = EVENT_ALLOC(eventAllocator, this);
+
+#ifdef ENABLE_EVENT_TRACKER
+  e->set_location();
+#endif
+
   e->callback_event = callback_event;
   e->cookie         = cookie;
-  return schedule_local(e->init(cont, get_hrtime() + t, 0));
+  return schedule_local(e->init(cont, ink_get_hrtime() + t, 0));
 }
 
 TS_INLINE Event *
 EThread::schedule_every_local(Continuation *cont, ink_hrtime t, int callback_event, void *cookie)
 {
-  Event *e          = EVENT_ALLOC(eventAllocator, this);
+  Event *e = EVENT_ALLOC(eventAllocator, this);
+
+#ifdef ENABLE_EVENT_TRACKER
+  e->set_location();
+#endif
+
   e->callback_event = callback_event;
   e->cookie         = cookie;
   if (t < 0) {
     return schedule_local(e->init(cont, t, t));
   } else {
-    return schedule_local(e->init(cont, get_hrtime() + t, t));
+    return schedule_local(e->init(cont, ink_get_hrtime() + t, t));
   }
 }
 
@@ -164,6 +204,10 @@ EThread::schedule_local(Event *e)
   // The continuation that gets scheduled later is not always the
   // client VC, it can be HttpCacheSM etc. so save the flags
   e->continuation->control_flags.set_flags(get_cont_flags().get_flags());
+
+  // If you need to schedule an event from a different thread, use Ethread::schedule_imm/at/in/every functions
+  ink_release_assert(this == this_ethread());
+
   EventQueueExternal.enqueue_local(e);
   return e;
 }
@@ -187,9 +231,7 @@ EThread::schedule_spawn(Continuation *c, int ev, void *cookie)
 TS_INLINE EThread *
 this_ethread()
 {
-  // The `dynamic_cast` has a significant performance impact (~6%).
-  // Reported by masaori and create PR #6281 to fix it.
-  return static_cast<EThread *>(ink_thread_getspecific(ethread_key));
+  return EThread::this_ethread_ptr;
 }
 
 TS_INLINE EThread *
