@@ -25,9 +25,8 @@
 
   Basic Threads
 
-
-
 **************************************************************************/
+
 #include "P_EventSystem.h"
 #include "tscore/ink_string.h"
 
@@ -35,30 +34,24 @@
 // Common Interface impl                     //
 ///////////////////////////////////////////////
 
-ink_hrtime Thread::cur_time = ink_get_hrtime_internal();
-inkcoreapi ink_thread_key Thread::thread_data_key;
-
-namespace
-{
-static bool initialized ATS_UNUSED = ([]() -> bool {
-  // File scope initialization goes here.
-  ink_thread_key_create(&Thread::thread_data_key, nullptr);
-  return true;
-})();
-}
+thread_local Thread *Thread::this_thread_ptr;
 
 Thread::Thread()
 {
   mutex = new_ProxyMutex();
-  MUTEX_TAKE_LOCK(mutex, (EThread *)this);
+  MUTEX_TAKE_LOCK(mutex, static_cast<EThread *>(this));
   mutex->nthread_holding += THREAD_MUTEX_THREAD_HOLDING;
 }
 
 Thread::~Thread()
 {
-  ink_release_assert(mutex->thread_holding == (EThread *)this);
+  ink_release_assert(mutex->thread_holding == static_cast<EThread *>(this));
+  if (this_thread_ptr == this) {
+    this_thread_ptr = nullptr;
+  }
+
   mutex->nthread_holding -= THREAD_MUTEX_THREAD_HOLDING;
-  MUTEX_UNTAKE_LOCK(mutex, (EThread *)this);
+  MUTEX_UNTAKE_LOCK(mutex, static_cast<EThread *>(this));
 }
 
 ///////////////////////////////////////////////
@@ -66,7 +59,7 @@ Thread::~Thread()
 ///////////////////////////////////////////////
 
 struct thread_data_internal {
-  ThreadFunction f;                  ///< Function to excecute in the thread.
+  ThreadFunction f;                  ///< Function to execute in the thread.
   Thread *me;                        ///< The class instance.
   char name[MAX_THREAD_NAME_LENGTH]; ///< Name for the thread.
 };
