@@ -21,6 +21,8 @@
   limitations under the License.
  */
 
+#include <tscore/TSSystemState.h>
+
 //////////////////////////////////////////////////////////////////////
 //
 // The EThread Class
@@ -32,6 +34,8 @@
 #include <sys/eventfd.h>
 #endif
 
+#include <typeinfo>
+
 struct AIOCallback;
 
 #define NO_HEARTBEAT -1
@@ -45,10 +49,28 @@ char const *const EThread::STAT_NAME[] = {"proxy.process.eventloop.count",
 
 int const EThread::SAMPLE_COUNT[N_EVENT_TIMESCALES] = {10, 100, 1000};
 
-bool shutdown_event_system = false;
-
 int thread_max_heartbeat_mseconds = THREAD_MAX_HEARTBEAT_MSECONDS;
 
+// To define a class inherits from Thread:
+//   1) Define an independent thread_local static member
+//   2) Override Thread::set_specific() and assign that member and call Thread::set_specific()
+//   3) Define this_Xthread() which get thread specific data
+//   4) Clear thread specific data at destructor function.
+//
+// The below comments are copied from I_Thread.h
+//
+// Additionally, the EThread class (derived from Thread) maintains its
+// own independent data. All (and only) the threads created in the Event
+// Subsystem have this data.
+thread_local EThread *EThread::this_ethread_ptr;
+
+void
+EThread::set_specific()
+{
+  this_ethread_ptr = this;
+  Thread::set_specific();
+}
+
 EThread::EThread()
 {
   memset(thread_private, 0, PER_THREAD_DATA);
@@ -56,8 +78,6 @@ EThread::EThread()
 
 EThread::EThread(ThreadType att, int anid) : id(anid), tt(att)
 {
-  ethreads_to_be_signalled = (EThread **)ats_malloc(MAX_EVENT_THREADS * sizeof(EThread *));
-  memset(ethreads_to_be_signalled, 0, MAX_EVENT_THREADS * sizeof(EThread *));
   memset(thread_private, 0, PER_THREAD_DATA);
 #if HAVE_EVENTFD
   evfd = eventfd(0, EFD_NONBLOCK | EFD_CLOEXEC);
@@ -94,12 +114,10 @@ EThread::EThread(ThreadType att, Event *e) : tt(att), start_event(e)
 // threads won't have to deal with EThread memory deallocation.
 EThread::~EThread()
 {
-  if (n_ethreads_to_be_signalled > 0) {
-    flush_signals(this);
+  ink_release_assert(mutex->thread_holding == static_cast<EThread *>(this));
+  if (this_ethread_ptr == this) {
+    this_ethread_ptr = nullptr;
   }
-  ats_free(ethreads_to_be_signalled);
-  // TODO: This can't be deleted ....
-  // delete[]l1_hash;
 }
 
 bool
@@ -118,9 +136,9 @@ void
 EThread::process_event(Event *e, int calling_code)
 {
   ink_assert((!e->in_the_prot_queue && !e->in_the_priority_queue));
-  MUTEX_TRY_LOCK_FOR(lock, e->mutex, this, e->continuation);
+  WEAK_MUTEX_TRY_LOCK(lock, e->mutex, this);
   if (!lock.is_locked()) {
-    e->timeout_at = cur_time + DELAY_FOR_RETRY;
+    e->timeout_at = ink_get_hrtime() + DELAY_FOR_RETRY;
     EventQueueExternal.enqueue_local(e);
   } else {
     if (e->cancelled) {
@@ -128,6 +146,10 @@ EThread::process_event(Event *e, int calling_code)
       return;
     }
     Continuation *c_temp = e->continuation;
+
+    // Restore the client IP debugging flags
+    set_cont_flags(e->continuation->control_flags);
+
     e->continuation->handleEvent(calling_code, e);
     ink_assert(!e->in_the_priority_queue);
     ink_assert(c_temp == e->continuation);
@@ -137,11 +159,7 @@ EThread::process_event(Event *e, int calling_code)
         if (e->period < 0) {
           e->timeout_at = e->period;
         } else {
-          this->get_hrtime_updated();
-          e->timeout_at = cur_time + e->period;
-          if (e->timeout_at < cur_time) {
-            e->timeout_at = cur_time;
-          }
+          e->timeout_at = ink_get_hrtime() + e->period;
         }
         EventQueueExternal.enqueue_local(e);
       }
@@ -169,7 +187,7 @@ EThread::process_queue(Que(Event, link) * NegativeQueue, int *ev_count, int *nq_
       ink_assert(e->period == 0);
       process_event(e, e->callback_event);
     } else if (e->timeout_at > 0) { // INTERVAL
-      EventQueue.enqueue(e, cur_time);
+      EventQueue.enqueue(e, ink_get_hrtime());
     } else { // NEGATIVE
       Event *p = nullptr;
       Event *a = NegativeQueue->head;
@@ -192,27 +210,27 @@ EThread::execute_regular()
 {
   Event *e;
   Que(Event, link) NegativeQueue;
-  ink_hrtime next_time = 0;
-  ink_hrtime delta     = 0;    // time spent in the event loop
+  ink_hrtime next_time;
+  ink_hrtime delta;            // time spent in the event loop
   ink_hrtime loop_start_time;  // Time the loop started.
   ink_hrtime loop_finish_time; // Time at the end of the loop.
 
   // Track this so we can update on boundary crossing.
-  EventMetrics *prev_metric = this->prev(metrics + (ink_get_hrtime_internal() / HRTIME_SECOND) % N_EVENT_METRICS);
+  EventMetrics *prev_metric = this->prev(metrics + (ink_get_hrtime() / HRTIME_SECOND) % N_EVENT_METRICS);
 
-  int nq_count = 0;
-  int ev_count = 0;
+  int nq_count;
+  int ev_count;
 
   // A statically initialized instance we can use as a prototype for initializing other instances.
   static EventMetrics METRIC_INIT;
 
   // give priority to immediate events
   for (;;) {
-    if (unlikely(shutdown_event_system == true)) {
+    if (TSSystemState::is_event_system_shut_down()) {
       return;
     }
 
-    loop_start_time = Thread::get_hrtime_updated();
+    loop_start_time = ink_get_hrtime();
     nq_count        = 0; // count # of elements put on negative queue.
     ev_count        = 0; // # of events handled.
 
@@ -233,8 +251,8 @@ EThread::execute_regular()
     do {
       done_one = false;
       // execute all the eligible internal events
-      EventQueue.check_ready(cur_time, this);
-      while ((e = EventQueue.dequeue_ready(cur_time))) {
+      EventQueue.check_ready(loop_start_time, this);
+      while ((e = EventQueue.dequeue_ready(ink_get_hrtime()))) {
         ink_assert(e);
         ink_assert(e->timeout_at > 0);
         if (e->cancelled) {
@@ -257,22 +275,24 @@ EThread::execute_regular()
     }
 
     next_time             = EventQueue.earliest_timeout();
-    ink_hrtime sleep_time = next_time - Thread::get_hrtime_updated();
+    ink_hrtime sleep_time = next_time - ink_get_hrtime();
     if (sleep_time > 0) {
-      sleep_time = std::min(sleep_time, HRTIME_MSECONDS(thread_max_heartbeat_mseconds));
+      if (EventQueueExternal.localQueue.empty()) {
+        sleep_time = std::min(sleep_time, HRTIME_MSECONDS(thread_max_heartbeat_mseconds));
+      } else {
+        // Because of a missed lock, Timed-Event and Negative-Event have been pushed into localQueue for retry in awhile.
+        // Therefore, we have to set the limitation of sleep time in order to handle the next retry in time.
+        sleep_time = std::min(sleep_time, DELAY_FOR_RETRY);
+      }
       ++(current_metric->_wait);
     } else {
       sleep_time = 0;
     }
 
-    if (n_ethreads_to_be_signalled) {
-      flush_signals(this);
-    }
-
     tail_cb->waitForActivity(sleep_time);
 
     // loop cleanup
-    loop_finish_time = this->get_hrtime_updated();
+    loop_finish_time = ink_get_hrtime();
     delta            = loop_finish_time - loop_start_time;
 
     // This can happen due to time of day adjustments (which apparently happen quite frequently). I
@@ -322,7 +342,16 @@ EThread::execute()
 
   switch (tt) {
   case REGULAR: {
+    /* The Event Thread has two status: busy and sleep:
+     *   - Keep `EThread::lock` locked while Event Thread is busy,
+     *   - The `EThread::lock` is released while Event Thread is sleep.
+     * When other threads try to acquire the `EThread::lock` of the target Event Thread:
+     *   - Acquired, indicating that the target Event Thread is sleep,
+     *   - Failed, indicating that the target Event Thread is busy.
+     */
+    ink_mutex_acquire(&EventQueueExternal.lock);
     this->execute_regular();
+    ink_mutex_release(&EventQueueExternal.lock);
     break;
   }
   case DEDICATED: {
