@@ -121,7 +121,7 @@ UDPConnection::send(Continuation *c, UDPPacket *xp)
   if (shouldDestroy()) {
     ink_assert(!"freeing packet sent on dead connection");
     p->free();
-    return ACTION_RESULT_NONE;
+    return nullptr;
   }
 
   ink_assert(mutex == c->mutex);
@@ -132,7 +132,7 @@ UDPConnection::send(Continuation *c, UDPPacket *xp)
   mutex               = c->mutex;
   p->reqGenerationNum = conn->sendGenerationNum;
   get_UDPNetHandler(conn->ethread)->udpOutQueue.send(p);
-  return ACTION_RESULT_NONE;
+  return nullptr;
 }
 
 void
