@@ -36,6 +36,7 @@
 #include "QUICPinger.h"
 #include "QUICPadder.h"
 #include "QUICHandshakeProtocol.h"
+#include "QUICStreamAdapter.h"
 
 class MockQUICContext;
 
@@ -45,25 +46,25 @@ std::string_view negotiated_application_name_sv = "h3-29"sv;
 class MockQUICLDConfig : public QUICLDConfig
 {
   uint32_t
-  packet_threshold() const
+  packet_threshold() const override
   {
     return 3;
   }
 
   float
-  time_threshold() const
+  time_threshold() const override
   {
     return 1.25;
   }
 
   ink_hrtime
-  granularity() const
+  granularity() const override
   {
     return HRTIME_MSECONDS(1);
   }
 
   ink_hrtime
-  initial_rtt() const
+  initial_rtt() const override
   {
     return HRTIME_MSECONDS(100);
   }
@@ -78,25 +79,25 @@ class MockQUICCCConfig : public QUICCCConfig
   }
 
   uint32_t
-  initial_window() const
+  initial_window() const override
   {
     return 10;
   }
 
   uint32_t
-  minimum_window() const
+  minimum_window() const override
   {
     return 2;
   }
 
   float
-  loss_reduction_factor() const
+  loss_reduction_factor() const override
   {
     return 0.5;
   }
 
   uint32_t
-  persistent_congestion_threshold() const
+  persistent_congestion_threshold() const override
   {
     return 2;
   }
@@ -107,22 +108,22 @@ class MockQUICPathManager : public QUICPathManager
 public:
   virtual ~MockQUICPathManager() {}
   virtual const QUICPath &
-  get_current_path()
+  get_current_path() override
   {
     return _path;
   }
   virtual const QUICPath &
-  get_verified_path()
+  get_verified_path() override
   {
     return _path;
   }
   virtual void
-  open_new_path(const QUICPath &path, ink_hrtime timeout_in)
+  open_new_path(const QUICPath &path, ink_hrtime timeout_in) override
   {
     return;
   }
   virtual void
-  set_trusted_path(const QUICPath &path)
+  set_trusted_path(const QUICPath &path) override
   {
     return;
   }
@@ -194,13 +195,6 @@ class MockQUICConnectionInfoProvider : public QUICConnectionInfoProvider
     return NET_VCONNECTION_OUT;
   }
 
-  int
-  select_next_protocol(SSL *ssl, const unsigned char **out, unsigned char *outlen, const unsigned char *in,
-                       unsigned inlen) const override
-  {
-    return SSL_TLSEXT_ERR_OK;
-  }
-
   bool
   is_closed() const override
   {
@@ -294,58 +288,58 @@ class MockNetVConnection : public NetVConnection
 public:
   MockNetVConnection(NetVConnectionContext_t context = NET_VCONNECTION_OUT) : NetVConnection() { netvc_context = context; }
   VIO *
-  do_io_read(Continuation *c, int64_t nbytes, MIOBuffer *buf)
+  do_io_read(Continuation *c, int64_t nbytes, MIOBuffer *buf) override
   {
     return nullptr;
   };
   VIO *
-  do_io_write(Continuation *c, int64_t nbytes, IOBufferReader *buf, bool owner = false)
+  do_io_write(Continuation *c, int64_t nbytes, IOBufferReader *buf, bool owner = false) override
   {
     return nullptr;
   };
-  void do_io_close(int lerrno = -1){};
-  void do_io_shutdown(ShutdownHowTo_t howto){};
-  void reenable(VIO *vio){};
-  void reenable_re(VIO *vio){};
-  void set_active_timeout(ink_hrtime timeout_in){};
-  void set_inactivity_timeout(ink_hrtime timeout_in){};
-  void cancel_active_timeout(){};
-  void cancel_inactivity_timeout(){};
-  void add_to_keep_alive_queue(){};
-  void remove_from_keep_alive_queue(){};
+  void do_io_close(int lerrno = -1) override{};
+  void do_io_shutdown(ShutdownHowTo_t howto) override{};
+  void reenable(VIO *vio) override{};
+  void reenable_re(VIO *vio) override{};
+  void set_active_timeout(ink_hrtime timeout_in) override{};
+  void set_inactivity_timeout(ink_hrtime timeout_in) override{};
+  void cancel_active_timeout() override{};
+  void cancel_inactivity_timeout() override{};
+  void add_to_keep_alive_queue() override{};
+  void remove_from_keep_alive_queue() override{};
   bool
-  add_to_active_queue()
+  add_to_active_queue() override
   {
     return true;
   };
   ink_hrtime
-  get_active_timeout()
+  get_active_timeout() override
   {
     return 0;
   }
   ink_hrtime
-  get_inactivity_timeout()
+  get_inactivity_timeout() override
   {
     return 0;
   }
   void
-  apply_options()
+  apply_options() override
   {
   }
   SOCKET
-  get_socket() { return 0; }
+  get_socket() override { return 0; }
   int
   set_tcp_init_cwnd(int init_cwnd)
   {
     return 0;
   }
   int
-  set_tcp_congestion_control(int side)
+  set_tcp_congestion_control(int side) override
   {
     return 0;
   }
-  void set_local_addr(){};
-  void set_remote_addr(){};
+  void set_local_addr() override{};
+  void set_remote_addr() override{};
 
   NetVConnectionContext_t
   get_context() const
@@ -512,13 +506,6 @@ public:
     return negotiated_application_name_sv;
   }
 
-  int
-  select_next_protocol(SSL *ssl, const unsigned char **out, unsigned char *outlen, const unsigned char *in,
-                       unsigned inlen) const override
-  {
-    return SSL_TLSEXT_ERR_OK;
-  }
-
   int _transmit_count   = 0;
   int _retransmit_count = 0;
   Ptr<ProxyMutex> _mutex;
@@ -731,6 +718,76 @@ private:
   MockQUICCongestionController _cc;
 };
 
+class MockQUICStreamAdapter : public QUICStreamAdapter
+{
+public:
+  MockQUICStreamAdapter(QUICStream &stream) : QUICStreamAdapter(stream) {}
+
+  void
+  write_to_stream(const uint8_t *buf, size_t len)
+  {
+    this->_total_sending_data_len += len;
+    this->_sending_data_len += len;
+  }
+
+  int64_t
+  write(QUICOffset offset, const uint8_t *data, uint64_t data_length, bool fin) override
+  {
+    this->_total_receiving_data_len += data_length;
+    this->_receiving_data_len += data_length;
+    return data_length;
+  }
+  bool
+  is_eos() override
+  {
+    return false;
+  }
+  uint64_t
+  unread_len() override
+  {
+    return this->_sending_data_len;
+  }
+  uint64_t
+  read_len() override
+  {
+    return 0;
+  }
+  uint64_t
+  total_len() override
+  {
+    return this->_total_sending_data_len;
+  }
+  void
+  encourge_read() override
+  {
+  }
+  void
+  encourge_write() override
+  {
+  }
+  void
+  notify_eos() override
+  {
+  }
+
+protected:
+  Ptr<IOBufferBlock>
+  _read(size_t len) override
+  {
+    this->_sending_data_len -= len;
+    Ptr<IOBufferBlock> block = make_ptr<IOBufferBlock>(new_IOBufferBlock());
+    block->alloc(iobuffer_size_to_index(len, BUFFER_SIZE_INDEX_32K));
+    block->fill(len);
+    return block;
+  }
+
+private:
+  size_t _sending_data_len         = 0;
+  size_t _total_sending_data_len   = 0;
+  size_t _receiving_data_len       = 0;
+  size_t _total_receiving_data_len = 0;
+};
+
 class MockQUICApplication : public QUICApplication
 {
 public:
@@ -740,20 +797,29 @@ public:
   main_event_handler(int event, Event *data)
   {
     if (event == 12345) {
-      QUICStreamIO *stream_io = static_cast<QUICStreamIO *>(data->cookie);
-      stream_io->write_reenable();
     }
     return EVENT_CONT;
   }
 
+  void
+  on_new_stream(QUICStream &stream) override
+  {
+    auto ite                   = this->_streams.emplace(stream.id(), stream);
+    QUICStreamAdapter &adapter = ite.first->second;
+    stream.set_io_adapter(&adapter);
+  }
+
   void
   send(const uint8_t *data, size_t size, QUICStreamId stream_id)
   {
-    QUICStreamIO *stream_io = this->_find_stream_io(stream_id);
-    stream_io->write(data, size);
+    auto ite      = this->_streams.find(stream_id);
+    auto &adapter = ite->second;
+    adapter.write_to_stream(data, size);
 
-    eventProcessor.schedule_imm(this, ET_CALL, 12345, stream_io);
+    // eventProcessor.schedule_imm(this, ET_CALL, 12345, adapter);
   }
+
+  std::unordered_map<QUICStreamId, MockQUICStreamAdapter> _streams;
 };
 
 class MockQUICPacketR : public QUICPacketR
