@@ -80,7 +80,7 @@ mgmt_accept(int s, struct sockaddr *addr, socklen_t *addrlen)
   int r, retries;
   ink_assert(*addrlen != 0);
   for (retries = 0; retries < MGMT_MAX_TRANSIENT_ERRORS; retries++) {
-    r = ::accept(s, addr, (socklen_t *)addrlen);
+    r = ::accept(s, addr, addrlen);
     if (r >= 0) {
       return r;
     }
@@ -183,7 +183,7 @@ mgmt_select(int nfds, fd_set *readfds, fd_set *writefds, fd_set *errorfds, struc
 // Note: Linux select() has slight different semantics.  From the
 // man page: "On Linux, timeout is modified to reflect the amount of
 // time not slept; most other implementations do not do this."
-// Linux select() can also return ENOMEM, so we espeically need to
+// Linux select() can also return ENOMEM, so we especially need to
 // protect the call with the transient error retry loop.
 // Fortunately, because of the Linux timeout handling, our
 // mgmt_select call will still timeout correctly, rather than
@@ -215,7 +215,7 @@ mgmt_sendto(int fd, void *buf, int len, int flags, struct sockaddr *to, int tole
 {
   int r, retries;
   for (retries = 0; retries < MGMT_MAX_TRANSIENT_ERRORS; retries++) {
-    r = ::sendto(fd, (char *)buf, len, flags, to, tolen);
+    r = ::sendto(fd, static_cast<char *>(buf), len, flags, to, tolen);
     if (r >= 0) {
       return r;
     }
@@ -266,7 +266,7 @@ mgmt_write_timeout(int fd, int sec, int usec)
   timeout.tv_sec  = sec;
   timeout.tv_usec = usec;
 
-  if (fd < 0 || fd >= (int)FD_SETSIZE) {
+  if (fd < 0 || fd >= FD_SETSIZE) {
     errno = EBADF;
     return -1;
   }
@@ -305,7 +305,7 @@ mgmt_read_timeout(int fd, int sec, int usec)
   timeout.tv_sec  = sec;
   timeout.tv_usec = usec;
 
-  if (fd < 0 || fd >= (int)FD_SETSIZE) {
+  if (fd < 0 || fd >= FD_SETSIZE) {
     errno = EBADF;
     return -1;
   }
