@@ -94,7 +94,7 @@ int mgmt_write_timeout(int fd, int sec, int usec);
 int mgmt_read_timeout(int fd, int sec, int usec);
 
 // Do we support passing Unix domain credentials on this platform?
-bool mgmt_has_peereid(void);
+bool mgmt_has_peereid();
 
 // Get the Unix domain peer credentials.
 int mgmt_get_peereid(int fd, uid_t *euid, gid_t *egid);
