@@ -75,11 +75,11 @@ static int OPEN_WRITE_FAIL_REQ_DELAY_TIMEOUT     = 500;
 
 static bool global_init = false;
 
-typedef struct _RequestData {
+using RequestData = struct _RequestData {
   TSHttpTxn txnp;
   int wl_retry; // write lock failure retry count
   std::string req_url;
-} RequestData;
+};
 
 static int
 add_redirect_header(TSMBuffer &bufp, TSMLoc &hdr_loc, const std::string &location)
@@ -172,7 +172,6 @@ on_immediate(RequestData *req, TSCont &contp)
   TSDebug(DEBUG_TAG, "continuation delayed, scheduling now..for url: %s", req->req_url.c_str());
 
   // add retry_done header to prevent looping
-  std::string value;
   TSMBuffer bufp;
   TSMLoc hdr_loc;
   if (TSHttpTxnClientRespGet(req->txnp, &bufp, &hdr_loc) != TS_SUCCESS) {
@@ -210,7 +209,7 @@ on_send_response_header(RequestData *req, TSHttpTxn &txnp, TSCont &contp)
     if (delay_request) {
       req->wl_retry++;
       TSDebug(DEBUG_TAG, "delaying request, url@%p: {{%s}} on retry: %d time", txnp, req->req_url.c_str(), req->wl_retry);
-      TSContSchedule(contp, OPEN_WRITE_FAIL_REQ_DELAY_TIMEOUT, TS_THREAD_POOL_TASK);
+      TSContScheduleOnPool(contp, OPEN_WRITE_FAIL_REQ_DELAY_TIMEOUT, TS_THREAD_POOL_TASK);
       TSHandleMLocRelease(bufp, TS_NULL_MLOC, hdr_loc);
       return TS_SUCCESS;
     }
@@ -312,9 +311,9 @@ process_args(int argc, const char **argv)
   // basic argv processing..
   for (int i = 1; i < argc; ++i) {
     if (strncmp(argv[i], "--delay=", 8) == 0) {
-      OPEN_WRITE_FAIL_REQ_DELAY_TIMEOUT = atoi((char *)(argv[i] + 8));
+      OPEN_WRITE_FAIL_REQ_DELAY_TIMEOUT = atoi(const_cast<char *>(argv[i] + 8));
     } else if (strncmp(argv[i], "--retries=", 10) == 0) {
-      OPEN_WRITE_FAIL_MAX_REQ_DELAY_RETRIES = atoi((char *)(argv[i] + 10));
+      OPEN_WRITE_FAIL_MAX_REQ_DELAY_RETRIES = atoi(const_cast<char *>(argv[i] + 10));
     }
   }
 }
@@ -327,7 +326,7 @@ TSPluginInit(int argc, const char *argv[])
 {
   TSPluginRegistrationInfo info;
 
-  info.plugin_name   = (char *)DEBUG_TAG;
+  info.plugin_name   = const_cast<char *>(DEBUG_TAG);
   info.vendor_name   = (char *)"Apache Software Foundation";
   info.support_email = (char *)"dev@trafficserver.apache.org";
 
@@ -353,7 +352,7 @@ TSRemapInit(TSRemapInterface * /* api_info */, char * /* errbuf */, int /* errbu
     TSError("Cannot initialize %s as both global and remap plugin", DEBUG_TAG);
     return TS_ERROR;
   } else {
-    TSDebug(DEBUG_TAG, "plugin is succesfully initialized for remap");
+    TSDebug(DEBUG_TAG, "plugin is successfully initialized for remap");
     return TS_SUCCESS;
   }
 }
