@@ -66,18 +66,18 @@ class ChunkDecoder
     };
   };
 
-  State::STATES state_;
-  int64_t size_;
+  State::STATES state_ = State::kSize;
+  int64_t size_        = 0;
 
 public:
-  ChunkDecoder(void) : state_(State::kSize), size_(0) {}
+  ChunkDecoder() {}
   void parseSizeCharacter(const char);
   int parseSize(const char *, const int64_t);
   int decode(const TSIOBufferReader &);
-  bool isSizeState(void) const;
+  bool isSizeState() const;
 
   inline bool
-  isEnd(void) const
+  isEnd() const
   {
     return state_ == State::kEnd;
   }
