@@ -179,9 +179,9 @@ MC::die()
   if (cbuf) {
     free_MIOBuffer(cbuf);
   }
-  if (tbuf) {
-    ats_free(tbuf);
-  }
+
+  ats_free(tbuf);
+
   mutex = NULL;
   theMCAllocator.free(this);
   return EVENT_DONE;
@@ -224,10 +224,10 @@ MC::add_binary_header(uint16_t err, uint8_t hdr_len, uint16_t key_len, uint32_t
 
   r.response.magic    = static_cast<uint8_t>(PROTOCOL_BINARY_RES);
   r.response.opcode   = binary_header.request.opcode;
-  r.response.keylen   = (uint16_t)htons(key_len);
+  r.response.keylen   = static_cast<uint16_t>(htons(key_len));
   r.response.extlen   = hdr_len;
   r.response.datatype = static_cast<uint8_t>(PROTOCOL_BINARY_RAW_BYTES);
-  r.response.status   = (uint16_t)htons(err);
+  r.response.status   = static_cast<uint16_t>(htons(err));
   r.response.bodylen  = htonl(body_len);
   r.response.opaque   = binary_header.request.opaque;
   r.response.cas      = ink_hton64(header.cas);
@@ -351,9 +351,9 @@ MC::read_from_client()
     cbuf->clear();
   }
   ink_assert(!crvc && !cwvc);
-  if (tbuf) {
-    ats_free(tbuf);
-  }
+
+  ats_free(tbuf);
+
   return TS_SET_CALL(&MC::read_from_client_event, VC_EVENT_READ_READY, rvio);
 }
 
@@ -444,7 +444,7 @@ MC::cache_read_event(int event, void *data)
       goto Lfail;
     }
     {
-      ink_hrtime t = Thread::get_hrtime();
+      ink_hrtime t = ink_get_hrtime();
       if ((static_cast<ink_hrtime>(rcache_header->settime)) <= last_flush ||
           t >= (static_cast<ink_hrtime>(rcache_header->settime)) + HRTIME_SECONDS(rcache_header->exptime)) {
         goto Lfail;
@@ -777,7 +777,7 @@ MC::ascii_set_event(int event, void *data)
       if (header.nkey != wcache_header->nkey || hlen < static_cast<int>(sizeof(MCCacheHeader) + wcache_header->nkey)) {
         goto Lfail;
       }
-      ink_hrtime t = Thread::get_hrtime();
+      ink_hrtime t = ink_get_hrtime();
       if ((static_cast<ink_hrtime>(wcache_header->settime)) <= last_flush ||
           t >= (static_cast<ink_hrtime>(wcache_header->settime)) + HRTIME_SECONDS(wcache_header->exptime)) {
         goto Lstale;
@@ -792,7 +792,7 @@ MC::ascii_set_event(int event, void *data)
       }
     }
     memcpy(tmp_cache_header_key, key, header.nkey);
-    header.settime = Thread::get_hrtime();
+    header.settime = ink_get_hrtime();
     if (exptime) {
       if (exptime > REALTIME_MAXDELTA) {
         if (HRTIME_SECONDS(exptime) <= (static_cast<ink_hrtime>(header.settime))) {
@@ -937,7 +937,7 @@ MC::ascii_incr_decr_event(int event, void *data)
         if (header.nkey != wcache_header->nkey || hlen < static_cast<int>(sizeof(MCCacheHeader) + wcache_header->nkey)) {
           goto Lfail;
         }
-        ink_hrtime t = Thread::get_hrtime();
+        ink_hrtime t = ink_get_hrtime();
         if ((static_cast<ink_hrtime>(wcache_header->settime)) <= last_flush ||
             t >= (static_cast<ink_hrtime>(wcache_header->settime)) + HRTIME_SECONDS(wcache_header->exptime)) {
           goto Lfail;
@@ -946,7 +946,7 @@ MC::ascii_incr_decr_event(int event, void *data)
         goto Lfail;
       }
       memcpy(tmp_cache_header_key, key, header.nkey);
-      header.settime = Thread::get_hrtime();
+      header.settime = ink_get_hrtime();
       if (exptime) {
         if (exptime > REALTIME_MAXDELTA) {
           if (HRTIME_SECONDS(exptime) <= (static_cast<ink_hrtime>(header.settime))) {
@@ -1385,7 +1385,7 @@ MC::read_ascii_from_client_event(int event, void *data)
       GET_NUM(time_offset);
     }
     f.noreply                 = is_noreply(&s, e);
-    ink_hrtime new_last_flush = Thread::get_hrtime() + HRTIME_SECONDS(time_offset);
+    ink_hrtime new_last_flush = ink_get_hrtime() + HRTIME_SECONDS(time_offset);
 #if __WORDSIZE == 64
     last_flush = new_last_flush; // this will be atomic for native word size
 #else
