@@ -90,6 +90,8 @@ ConditionMethod::initialize(Parser &p)
 
   match->set(p.get_arg());
   _matcher = match;
+
+  require_resources(RSRC_CLIENT_REQUEST_HEADERS);
 }
 
 bool
@@ -291,7 +293,7 @@ ConditionUrl::append_value(std::string &s, const Resources &res)
     // CLIENT always uses the pristine URL
     TSDebug(PLUGIN_NAME, "   Using the pristine url");
     if (TSHttpTxnPristineUrlGet(res.txnp, &bufp, &url) != TS_SUCCESS) {
-      TSError("[header_rewrite] Error getting the pristine URL");
+      TSError("[%s] Error getting the pristine URL", PLUGIN_NAME);
       return;
     }
   } else if (res._rri != nullptr) {
@@ -307,7 +309,7 @@ ConditionUrl::append_value(std::string &s, const Resources &res)
       TSDebug(PLUGIN_NAME, "   Using the to url");
       url = res._rri->mapToUrl;
     } else {
-      TSError("[header_rewrite] Invalid option value");
+      TSError("[%s] Invalid option value", PLUGIN_NAME);
       return;
     }
   } else {
@@ -315,11 +317,11 @@ ConditionUrl::append_value(std::string &s, const Resources &res)
       bufp           = res.bufp;
       TSMLoc hdr_loc = res.hdr_loc;
       if (TSHttpHdrUrlGet(bufp, hdr_loc, &url) != TS_SUCCESS) {
-        TSError("[header_rewrite] Error getting the URL");
+        TSError("[%s] Error getting the URL", PLUGIN_NAME);
         return;
       }
     } else {
-      TSError("[header_rewrite] Rule not supported at this hook");
+      TSError("[%s] Rule not supported at this hook", PLUGIN_NAME);
       return;
     }
   }
@@ -398,7 +400,7 @@ ConditionDBM::initialize(Parser &p)
     //   TSDebug(PLUGIN_NAME, "Opened DBM file %s", _file.c_str());
     //   _key.set_value(_qualifier.substr(pos + 1));
     // } else {
-    //   TSError("Failed to open DBM file: %s", _file.c_str());
+    //   TSError("[%s] Failed to open DBM file: %s", PLUGIN_NAME, _file.c_str());
     // }
   } else {
     TSError("[%s] Malformed DBM condition", PLUGIN_NAME);
@@ -528,10 +530,17 @@ ConditionIp::initialize(Parser &p)
 {
   Condition::initialize(p);
 
-  MatcherType *match = new MatcherType(_cond_op);
+  if (_cond_op == MATCH_IP_RANGES) { // Special hack for IP ranges for now ...
+    MatcherTypeIp *match = new MatcherTypeIp(_cond_op);
 
-  match->set(p.get_arg());
-  _matcher = match;
+    match->set(p.get_arg());
+    _matcher = match;
+  } else {
+    MatcherType *match = new MatcherType(_cond_op);
+
+    match->set(p.get_arg());
+    _matcher = match;
+  }
 }
 
 void
@@ -557,14 +566,39 @@ ConditionIp::set_qualifier(const std::string &q)
 bool
 ConditionIp::eval(const Resources &res)
 {
-  std::string s;
+  if (_matcher->op() == MATCH_IP_RANGES) {
+    const sockaddr *addr = nullptr;
 
-  append_value(s, res);
-  bool rval = static_cast<const Matchers<std::string> *>(_matcher)->test(s);
+    switch (_ip_qual) {
+    case IP_QUAL_CLIENT:
+      addr = TSHttpTxnClientAddrGet(res.txnp);
+      break;
+    case IP_QUAL_INBOUND:
+      addr = TSHttpTxnIncomingAddrGet(res.txnp);
+      break;
+    case IP_QUAL_SERVER:
+      addr = TSHttpTxnServerAddrGet(res.txnp);
+      break;
+    case IP_QUAL_OUTBOUND:
+      addr = TSHttpTxnOutgoingAddrGet(res.txnp);
+      break;
+    }
 
-  TSDebug(PLUGIN_NAME, "Evaluating IP(): %s - rval: %d", s.c_str(), rval);
+    if (addr) {
+      return static_cast<const Matchers<const sockaddr *> *>(_matcher)->test(addr);
+    } else {
+      return false;
+    }
+  } else {
+    std::string s;
 
-  return rval;
+    append_value(s, res);
+    bool rval = static_cast<const Matchers<std::string> *>(_matcher)->test(s);
+
+    TSDebug(PLUGIN_NAME, "Evaluating IP(): %s - rval: %d", s.c_str(), rval);
+
+    return rval;
+  }
 }
 
 void
@@ -584,6 +618,7 @@ ConditionIp::append_value(std::string &s, const Resources &res)
     ip_set = (nullptr != getIP(TSHttpTxnServerAddrGet(res.txnp), ip));
     break;
   case IP_QUAL_OUTBOUND:
+    TSDebug(PLUGIN_NAME, "Requesting output ip");
     ip_set = (nullptr != getIP(TSHttpTxnOutgoingAddrGet(res.txnp), ip));
     break;
   }
@@ -1029,10 +1064,17 @@ ConditionInbound::initialize(Parser &p)
 {
   Condition::initialize(p);
 
-  MatcherType *match = new MatcherType(_cond_op);
+  if (_cond_op == MATCH_IP_RANGES) { // Special hack for IP ranges for now ...
+    MatcherTypeIp *match = new MatcherTypeIp(_cond_op);
 
-  match->set(p.get_arg());
-  _matcher = match;
+    match->set(p.get_arg());
+    _matcher = match;
+  } else {
+    MatcherType *match = new MatcherType(_cond_op);
+
+    match->set(p.get_arg());
+    _matcher = match;
+  }
 }
 
 void
@@ -1070,14 +1112,38 @@ ConditionInbound::set_qualifier(const std::string &q)
 bool
 ConditionInbound::eval(const Resources &res)
 {
-  std::string s;
+  // Special hack for IP-Ranges since we really don't need to do a string conversion for the comparison.
+  if (_matcher->op() == MATCH_IP_RANGES) {
+    const sockaddr *addr = nullptr;
 
-  append_value(s, res);
-  bool rval = static_cast<const Matchers<std::string> *>(_matcher)->test(s);
+    switch (_net_qual) {
+    case NET_QUAL_LOCAL_ADDR:
+      addr = TSHttpTxnIncomingAddrGet(res.txnp);
+      break;
+    case NET_QUAL_REMOTE_ADDR:
+      addr = TSHttpTxnClientAddrGet(res.txnp);
+      break;
+    default:
+      // Only support actual IP addresses of course...
+      TSError("[%s] %%{%s:%s} is not supported, only IP-Addresses allowed", PLUGIN_NAME, TAG, get_qualifier().c_str());
+      break;
+    }
 
-  TSDebug(PLUGIN_NAME, "Evaluating %s(): %s - rval: %d", TAG, s.c_str(), rval);
+    if (addr) {
+      return static_cast<const Matchers<const sockaddr *> *>(_matcher)->test(addr);
+    } else {
+      return false;
+    }
+  } else {
+    std::string s;
 
-  return rval;
+    append_value(s, res);
+    bool rval = static_cast<const Matchers<std::string> *>(_matcher)->test(s);
+
+    TSDebug(PLUGIN_NAME, "Evaluating %s(): %s - rval: %d", TAG, s.c_str(), rval);
+
+    return rval;
+  }
 }
 
 void
@@ -1272,3 +1338,101 @@ ConditionTcpInfo::append_value(std::string &s, Resources const &res)
   s += "-";
 #endif
 }
+
+void
+ConditionCache::initialize(Parser &p)
+{
+  Condition::initialize(p);
+  MatcherType *match = new MatcherType(_cond_op);
+
+  match->set(p.get_arg());
+  _matcher = match;
+}
+
+bool
+ConditionCache::eval(const Resources &res)
+{
+  std::string s;
+
+  append_value(s, res);
+  TSDebug(PLUGIN_NAME, "Evaluating CACHE()");
+
+  return static_cast<const MatcherType *>(_matcher)->test(s);
+}
+
+void
+ConditionCache::append_value(std::string &s, const Resources &res)
+{
+  TSHttpTxn txn = res.txnp;
+  int status;
+
+  static const char *names[] = {
+    "miss",      // TS_CACHE_LOOKUP_MISS,
+    "hit-stale", // TS_CACHE_LOOKUP_HIT_STALE,
+    "hit-fresh", // TS_CACHE_LOOKUP_HIT_FRESH,
+    "skipped"    // TS_CACHE_LOOKUP_SKIPPED
+  };
+
+  TSDebug(PLUGIN_NAME, "Appending CACHE() to evaluation value -> %s", s.c_str());
+
+  if (TSHttpTxnCacheLookupStatusGet(txn, &status) == TS_ERROR || status < 0 || status >= 4) {
+    TSDebug(PLUGIN_NAME, "Cache Status Invalid: %d", status);
+
+    s += "none";
+  } else {
+    TSDebug(PLUGIN_NAME, "Cache Status Valid: %d", status);
+
+    s += names[status];
+  }
+}
+
+// ConditionNextHop: request header.
+void
+ConditionNextHop::initialize(Parser &p)
+{
+  Condition::initialize(p);
+
+  MatcherType *match = new MatcherType(_cond_op);
+  match->set(p.get_arg());
+  _matcher = match;
+}
+
+void
+ConditionNextHop::set_qualifier(const std::string &q)
+{
+  Condition::set_qualifier(q);
+  TSDebug(PLUGIN_NAME, "\tParsing %%{NEXT-HOP:%s}", q.c_str());
+  _next_hop_qual = parse_next_hop_qualifier(q);
+}
+
+void
+ConditionNextHop::append_value(std::string &s, const Resources &res)
+{
+  switch (_next_hop_qual) {
+  case NEXT_HOP_HOST: {
+    char const *const name = TSHttpTxnNextHopNameGet(res.txnp);
+    if (nullptr != name) {
+      TSDebug(PLUGIN_NAME, "Appending '%s' to evaluation value", name);
+      s.append(name);
+    } else {
+      TSDebug(PLUGIN_NAME, "NextHopName is empty");
+    }
+  } break;
+  case NEXT_HOP_PORT: {
+    int const port = TSHttpTxnNextHopPortGet(res.txnp);
+    TSDebug(PLUGIN_NAME, "Appending '%d' to evaluation value", port);
+    s.append(std::to_string(port));
+  } break;
+  default:
+    TSReleaseAssert(!"All cases should have been handled");
+    break;
+  }
+}
+
+bool
+ConditionNextHop::eval(const Resources &res)
+{
+  std::string s;
+  append_value(s, res);
+  return static_cast<const Matchers<std::string> *>(_matcher)->test(s);
+}
