@@ -348,6 +348,7 @@ protected:
 class ConditionIp : public Condition
 {
   typedef Matchers<std::string> MatcherType;
+  typedef Matchers<const sockaddr *> MatcherTypeIp;
 
 public:
   explicit ConditionIp() { TSDebug(PLUGIN_NAME_DBG, "Calling CTOR for ConditionIp"); };
@@ -503,8 +504,9 @@ private:
 /// Information about the inbound (client) session.
 class ConditionInbound : public Condition
 {
-  using MatcherType = Matchers<std::string>;
-  using self        = ConditionInbound;
+  using MatcherType   = Matchers<std::string>;
+  using MatcherTypeIp = Matchers<const sockaddr *>;
+  using self          = ConditionInbound;
 
 public:
   explicit ConditionInbound() { TSDebug(PLUGIN_NAME_DBG, "Calling CTOR for ConditionInbound"); };
@@ -583,3 +585,47 @@ protected:
   bool eval(const Resources &res) override;
   void initialize_hooks() override; // Return status only valid in certain hooks
 };
+
+// Cache Lookup Results
+class ConditionCache : public Condition
+{
+  using MatcherType = Matchers<std::string>;
+
+public:
+  ConditionCache() { TSDebug(PLUGIN_NAME_DBG, "Calling CTOR for ConditionCache"); }
+
+  // noncopyable
+  ConditionCache(const ConditionCache &) = delete;
+  void operator=(const ConditionCache &) = delete;
+
+  void initialize(Parser &p) override;
+  void append_value(std::string &s, const Resources &res) override;
+
+protected:
+  bool eval(const Resources &res) override;
+};
+
+// Next Hop
+class ConditionNextHop : public Condition
+{
+  using MatcherType = Matchers<std::string>;
+
+public:
+  enum HostType { NAME, PORT };
+
+  explicit ConditionNextHop() { TSDebug(PLUGIN_NAME_DBG, "Calling CTOR for ConditionNextHop"); }
+
+  // noncopyable
+  ConditionNextHop(const ConditionNextHop &) = delete;
+  void operator=(const ConditionNextHop &) = delete;
+
+  void initialize(Parser &p) override;
+  void set_qualifier(const std::string &q) override;
+  void append_value(std::string &s, const Resources &res) override;
+
+protected:
+  bool eval(const Resources &res) override;
+
+private:
+  NextHopQualifiers _next_hop_qual = NEXT_HOP_NONE;
+};
