@@ -24,6 +24,7 @@
 #include <pthread.h>
 
 #include "ts_lua_util.h"
+#include "luajit.h"
 
 #define TS_LUA_MAX_STATE_COUNT 256
 
@@ -72,8 +73,8 @@ static char const *const ts_lua_g_stat_strs[] = {
 typedef struct {
   ts_lua_main_ctx *main_ctx_array;
 
-  int gc_kb;   // last collected gc in kb
-  int threads; // last collected number active threads
+  TSMgmtInt gc_kb;   // last collected gc in kb
+  TSMgmtInt threads; // last collected number active threads
 
   int stat_inds[TS_LUA_IND_SIZE]; // stats indices
 
@@ -183,8 +184,8 @@ collectStats(ts_lua_plugin_stats *const plugin_stats)
       ts_lua_ctx_stats *const stats = main_ctx->stats;
 
       TSMutexLock(stats->mutexp);
-      gc_kb_total += (TSMgmtInt)stats->gc_kb;
-      threads_total += (TSMgmtInt)stats->threads;
+      gc_kb_total += stats->gc_kb;
+      threads_total += stats->threads;
       TSMutexUnlock(stats->mutexp);
     }
   }
@@ -583,6 +584,75 @@ configHandler(TSCont contp, TSEvent event ATS_UNUSED, void *edata ATS_UNUSED)
   return 0;
 }
 
+static int
+vconnHookHandler(TSCont contp, TSEvent event, void *edata)
+{
+  TSVConn vconn = (TSVConn)edata;
+
+  int ret;
+  uint64_t req_id;
+
+  lua_State *l;
+
+  ts_lua_main_ctx *main_ctx;
+  ts_lua_vconn_ctx *vconn_ctx;
+
+  ts_lua_instance_conf *conf = (ts_lua_instance_conf *)TSContDataGet(contp);
+
+  main_ctx = pthread_getspecific(lua_g_state_key);
+  if (main_ctx == NULL) {
+    req_id = __sync_fetch_and_add(&ts_lua_g_http_next_id, 1);
+    TSDebug(TS_LUA_DEBUG_TAG, "[%s] req_id for vconn handler: %" PRId64, __FUNCTION__, req_id);
+    main_ctx = &ts_lua_g_main_ctx_array[req_id % conf->states];
+    pthread_setspecific(lua_g_state_key, main_ctx);
+  }
+
+  TSMutexLock(main_ctx->mutexp);
+
+  vconn_ctx        = ts_lua_create_vconn_ctx(main_ctx, conf);
+  vconn_ctx->vconn = vconn;
+  l                = vconn_ctx->lua;
+
+  switch (event) {
+  case TS_EVENT_VCONN_START:
+    lua_getglobal(l, TS_LUA_FUNCTION_G_VCONN_START);
+    break;
+
+  default:
+    ts_lua_destroy_vconn_ctx(vconn_ctx);
+    TSMutexUnlock(main_ctx->mutexp);
+    TSVConnReenable(vconn);
+    return 0;
+  }
+
+  if (lua_type(l, -1) != LUA_TFUNCTION) {
+    lua_pop(l, 1);
+    ts_lua_destroy_vconn_ctx(vconn_ctx);
+    TSMutexUnlock(main_ctx->mutexp);
+
+    TSVConnReenable(vconn);
+    return 0;
+  }
+
+  if (lua_pcall(l, 0, 1, 0) != 0) {
+    TSError("[ts_lua][%s] lua_pcall failed: %s", __FUNCTION__, lua_tostring(l, -1));
+  }
+
+  ret = lua_tointeger(l, -1);
+  lua_pop(l, 1);
+
+  ts_lua_destroy_vconn_ctx(vconn_ctx);
+
+  TSMutexUnlock(main_ctx->mutexp);
+  if (ret) {
+    TSError("[ts_lua][%s] error returned", __FUNCTION__);
+  } else {
+    TSDebug(TS_LUA_DEBUG_TAG, "[%s] no error returned", __FUNCTION__);
+  }
+  TSVConnReenable(vconn);
+  return 0;
+}
+
 static int
 globalHookHandler(TSCont contp, TSEvent event ATS_UNUSED, void *edata)
 {
@@ -661,14 +731,6 @@ globalHookHandler(TSCont contp, TSEvent event ATS_UNUSED, void *edata)
     break;
 
   case TS_EVENT_HTTP_SEND_RESPONSE_HDR:
-    // client response can be changed within a transaction
-    // (e.g. due to the follow redirect feature). So, clearing the pointers
-    // to allow API(s) to fetch the pointers again when it re-enters the hook
-    if (http_ctx->client_response_hdrp != NULL) {
-      TSHandleMLocRelease(http_ctx->client_response_bufp, TS_NULL_MLOC, http_ctx->client_response_hdrp);
-      http_ctx->client_response_bufp = NULL;
-      http_ctx->client_response_hdrp = NULL;
-    }
     lua_getglobal(l, TS_LUA_FUNCTION_G_SEND_RESPONSE);
     break;
 
@@ -725,14 +787,7 @@ globalHookHandler(TSCont contp, TSEvent event ATS_UNUSED, void *edata)
   ret = lua_tointeger(l, -1);
   lua_pop(l, 1);
 
-  // client response can be changed within a transaction
-  // (e.g. due to the follow redirect feature). So, clearing the pointers
-  // to allow API(s) to fetch the pointers again when it re-enters the hook
-  if (http_ctx->client_response_hdrp != NULL) {
-    TSHandleMLocRelease(http_ctx->client_response_bufp, TS_NULL_MLOC, http_ctx->client_response_hdrp);
-    http_ctx->client_response_bufp = NULL;
-    http_ctx->client_response_hdrp = NULL;
-  }
+  ts_lua_clear_http_ctx(http_ctx);
 
   if (http_ctx->has_hook) {
     // add a hook to release resources for context
@@ -790,9 +845,11 @@ TSPluginInit(int argc, const char *argv[])
 
   int states = ts_lua_max_state_count;
 
+  int jit                              = 1;
   int reload                           = 0;
   static const struct option longopt[] = {
     {"states", required_argument, 0, 's'},
+    {"jit", required_argument, 0, 'j'},
     {"enable-reload", no_argument, 0, 'r'},
     {0, 0, 0, 0},
   };
@@ -806,6 +863,19 @@ TSPluginInit(int argc, const char *argv[])
       states = atoi(optarg);
       // set state
       break;
+    case 'j':
+      jit = atoi(optarg);
+      if (jit == 0) {
+        TSDebug(TS_LUA_DEBUG_TAG, "[%s] disable JIT mode", __FUNCTION__);
+        for (int index = 0; index < ts_lua_max_state_count; ++index) {
+          ts_lua_main_ctx *const main_ctx = (ts_lua_g_main_ctx_array + index);
+          lua_State *const lstate         = main_ctx->lua;
+          if (luaJIT_setmode(lstate, 0, LUAJIT_MODE_ENGINE | LUAJIT_MODE_OFF) == 0) {
+            TSError("[ts_lua][%s] Failed to disable JIT mode", __FUNCTION__);
+          }
+        }
+      }
+      break;
     case 'r':
       reload = 1;
       TSDebug(TS_LUA_DEBUG_TAG, "[%s] enable global plugin reload [%d]", __FUNCTION__, reload);
@@ -856,7 +926,7 @@ TSPluginInit(int argc, const char *argv[])
 
   if (ret != 0) {
     TSError(errbuf, NULL);
-    TSError("[ts_lua][%s] ts_lua_add_module failed", __FUNCTION__);
+    TSEmergency("[ts_lua][%s] ts_lua_add_module failed", __FUNCTION__);
     return;
   }
 
@@ -951,6 +1021,26 @@ TSPluginInit(int argc, const char *argv[])
 
   ts_lua_destroy_http_ctx(http_ctx);
 
+  TSCont vconn_contp = TSContCreate(vconnHookHandler, NULL);
+  if (!vconn_contp) {
+    TSError("[ts_lua][%s] could not create vconn continuation", __FUNCTION__);
+    return;
+  }
+  TSContDataSet(vconn_contp, conf);
+
+  // adding hook based on whther the lua global vconn function exists
+  ts_lua_vconn_ctx *vconn_ctx = ts_lua_create_vconn_ctx(main_ctx, conf);
+  lua_State *vl               = vconn_ctx->lua;
+
+  lua_getglobal(vl, TS_LUA_FUNCTION_G_VCONN_START);
+  if (lua_type(vl, -1) == LUA_TFUNCTION) {
+    TSHttpHookAdd(TS_VCONN_START_HOOK, vconn_contp);
+    TSDebug(TS_LUA_DEBUG_TAG, "vconn_start_hook added");
+  }
+  lua_pop(vl, 1);
+
+  ts_lua_destroy_vconn_ctx(vconn_ctx);
+
   // support for reload as global plugin
   if (reload) {
     TSCont config_contp = TSContCreate(configHandler, NULL);
