@@ -30,10 +30,10 @@
 #define TRANSFORM_READ_READY (TRANSFORM_EVENTS_START + 0)
 
 typedef struct _RangeRecord {
-  _RangeRecord() : _start(-1), _end(-1), _done_byte(-1) {}
-  int64_t _start;
-  int64_t _end;
-  int64_t _done_byte;
+  _RangeRecord() {}
+  int64_t _start     = -1;
+  int64_t _end       = -1;
+  int64_t _done_byte = -1;
 } RangeRecord;
 
 class TransformProcessor
@@ -48,7 +48,7 @@ public:
                                     int content_type_len, int64_t content_length);
 };
 
-#ifdef TS_HAS_TESTS
+#if TS_HAS_TESTS
 class TransformTest
 {
 public:
