@@ -27,6 +27,7 @@
 #include <cassert>
 #include <cstdio>
 #include <cstring>
+#include <string_view>
 #include "HTTP.h"
 #include "HdrToken.h"
 #include "tscore/Diags.h"
@@ -85,6 +86,7 @@ const char *HTTP_VALUE_CLOSE;
 const char *HTTP_VALUE_COMPRESS;
 const char *HTTP_VALUE_DEFLATE;
 const char *HTTP_VALUE_GZIP;
+const char *HTTP_VALUE_BROTLI;
 const char *HTTP_VALUE_IDENTITY;
 const char *HTTP_VALUE_KEEP_ALIVE;
 const char *HTTP_VALUE_MAX_AGE;
@@ -120,6 +122,7 @@ int HTTP_LEN_CLOSE;
 int HTTP_LEN_COMPRESS;
 int HTTP_LEN_DEFLATE;
 int HTTP_LEN_GZIP;
+int HTTP_LEN_BROTLI;
 int HTTP_LEN_IDENTITY;
 int HTTP_LEN_KEEP_ALIVE;
 int HTTP_LEN_MAX_AGE;
@@ -218,6 +221,7 @@ http_init()
     HTTP_VALUE_COMPRESS             = hdrtoken_string_to_wks("compress");
     HTTP_VALUE_DEFLATE              = hdrtoken_string_to_wks("deflate");
     HTTP_VALUE_GZIP                 = hdrtoken_string_to_wks("gzip");
+    HTTP_VALUE_BROTLI               = hdrtoken_string_to_wks("br");
     HTTP_VALUE_IDENTITY             = hdrtoken_string_to_wks("identity");
     HTTP_VALUE_KEEP_ALIVE           = hdrtoken_string_to_wks("keep-alive");
     HTTP_VALUE_MAX_AGE              = hdrtoken_string_to_wks("max-age");
@@ -242,6 +246,7 @@ http_init()
     HTTP_LEN_COMPRESS             = hdrtoken_wks_to_length(HTTP_VALUE_COMPRESS);
     HTTP_LEN_DEFLATE              = hdrtoken_wks_to_length(HTTP_VALUE_DEFLATE);
     HTTP_LEN_GZIP                 = hdrtoken_wks_to_length(HTTP_VALUE_GZIP);
+    HTTP_LEN_BROTLI               = hdrtoken_wks_to_length(HTTP_VALUE_BROTLI);
     HTTP_LEN_IDENTITY             = hdrtoken_wks_to_length(HTTP_VALUE_IDENTITY);
     HTTP_LEN_KEEP_ALIVE           = hdrtoken_wks_to_length(HTTP_VALUE_KEEP_ALIVE);
     HTTP_LEN_MAX_AGE              = hdrtoken_wks_to_length(HTTP_VALUE_MAX_AGE);
@@ -873,7 +878,7 @@ http_parser_clear(HTTPParser *parser)
 
 ParseResult
 http_parser_parse_req(HTTPParser *parser, HdrHeap *heap, HTTPHdrImpl *hh, const char **start, const char *end,
-                      bool must_copy_strings, bool eof, bool strict_uri_parsing, size_t max_request_line_size,
+                      bool must_copy_strings, bool eof, int strict_uri_parsing, size_t max_request_line_size,
                       size_t max_hdr_field_size)
 {
   if (parser->m_parsing_http) {
@@ -970,6 +975,9 @@ http_parser_parse_req(HTTPParser *parser, HdrHeap *heap, HTTPHdrImpl *hh, const
       ParseResult ret = mime_parser_parse(&parser->m_mime_parser, heap, hh->m_fields_impl, start, end, must_copy_strings, eof,
                                           false, max_hdr_field_size);
       // If we're done with the main parse do some validation
+      if (ret == PARSE_RESULT_DONE) {
+        ret = validate_hdr_request_target(HTTP_WKSIDX_GET, url);
+      }
       if (ret == PARSE_RESULT_DONE) {
         ret = validate_hdr_host(hh); // check HOST header
       }
@@ -1125,6 +1133,9 @@ http_parser_parse_req(HTTPParser *parser, HdrHeap *heap, HTTPHdrImpl *hh, const
   ParseResult ret = mime_parser_parse(&parser->m_mime_parser, heap, hh->m_fields_impl, start, end, must_copy_strings, eof, false,
                                       max_hdr_field_size);
   // If we're done with the main parse do some validation
+  if (ret == PARSE_RESULT_DONE) {
+    ret = validate_hdr_request_target(hh->u.req.m_method_wks_idx, hh->u.req.m_url_impl);
+  }
   if (ret == PARSE_RESULT_DONE) {
     ret = validate_hdr_host(hh); // check HOST header
   }
@@ -1134,6 +1145,37 @@ http_parser_parse_req(HTTPParser *parser, HdrHeap *heap, HTTPHdrImpl *hh, const
   return ret;
 }
 
+ParseResult
+validate_hdr_request_target(int method_wk_idx, URLImpl *url)
+{
+  ParseResult ret = PARSE_RESULT_DONE;
+  int host_len;
+  url->get_host(&host_len);
+  int path_len;
+  const char *path = url->get_path(&path_len);
+  int scheme_len;
+  url->get_scheme(&scheme_len);
+
+  if (host_len == 0) {
+    if (path_len == 1 && path[0] == '*') { // asterisk-form
+      // Skip this check for now because URLImpl can't distinguish '*' and '/*'
+      // if (method_wk_idx != HTTP_WKSIDX_OPTIONS) {
+      //   ret = PARSE_RESULT_ERROR;
+      // }
+    } else { // origin-form
+      // Nothing to check here
+    }
+  } else if (scheme_len == 0 && host_len != 0) { // authority-form
+    if (method_wk_idx != HTTP_WKSIDX_CONNECT) {
+      ret = PARSE_RESULT_ERROR;
+    }
+  } else { // absolute-form
+    // Nothing to check here
+  }
+
+  return ret;
+}
+
 ParseResult
 validate_hdr_host(HTTPHdrImpl *hh)
 {
@@ -1195,26 +1237,27 @@ validate_hdr_content_length(HdrHeap *heap, HTTPHdrImpl *hh)
     // recipient MUST treat it as an unrecoverable error.  If this is a
     // request message, the server MUST respond with a 400 (Bad Request)
     // status code and then close the connection
-    int content_length_len         = 0;
-    const char *content_length_val = content_length_field->value_get(&content_length_len);
+    std::string_view value = content_length_field->value_get();
 
-    // RFC 7230 section 3.3.2
+    // RFC 9110 section 8.6.
     // Content-Length = 1*DIGIT
     //
+    if (value.empty()) {
+      Debug("http", "Content-Length headers don't match the ABNF, returning parse error");
+      return PARSE_RESULT_ERROR;
+    }
+
     // If the content-length value contains a non-numeric value, the header is invalid
-    for (int i = 0; i < content_length_len; i++) {
-      if (!isdigit(content_length_val[i])) {
-        Debug("http", "Content-Length value contains non-digit, returning parse error");
-        return PARSE_RESULT_ERROR;
-      }
+    if (std::find_if(value.cbegin(), value.cend(), [](std::string_view::value_type c) { return !std::isdigit(c); }) !=
+        value.cend()) {
+      Debug("http", "Content-Length value contains non-digit, returning parse error");
+      return PARSE_RESULT_ERROR;
     }
 
     while (content_length_field->has_dups()) {
-      int content_length_len_2         = 0;
-      const char *content_length_val_2 = content_length_field->m_next_dup->value_get(&content_length_len_2);
+      std::string_view value_dup = content_length_field->m_next_dup->value_get();
 
-      if ((content_length_len != content_length_len_2) ||
-          (memcmp(content_length_val, content_length_val_2, content_length_len) != 0)) {
+      if ((value.length() != value_dup.length()) || value.compare(value_dup) != 0) {
         // Values are different, parse error
         Debug("http", "Content-Length headers don't match, returning parse error");
         return PARSE_RESULT_ERROR;
