@@ -40,7 +40,9 @@ enum URLType {
   URL_TYPE_HTTPS,
 };
 
-struct URLImpl : public HdrHeapObjImpl {
+class URLImpl : public HdrHeapObjImpl
+{
+public:
   // HdrHeapObjImpl is 4 bytes
   uint16_t m_len_scheme;
   uint16_t m_len_user;
@@ -79,6 +81,31 @@ struct URLImpl : public HdrHeapObjImpl {
   uint32_t m_normalization_flags : 2; // Only valid if both m_clean and m_ptr_printed_sting are non-zero.
   // 8 bytes + 4 bits, will result in padding
 
+  // Accessors
+  const char *get_scheme(int *length);
+  const char *set_scheme(HdrHeap *heap, const char *value, int value_wks_idx, int length, bool copy_string);
+  const char *get_user(int *length);
+  void set_user(HdrHeap *heap, const char *value, int length, bool copy_string);
+  const char *get_password(int *length);
+  void set_password(HdrHeap *heap, const char *value, int length, bool copy_string);
+  const char *get_host(int *length);
+  void set_host(HdrHeap *heap, const char *value, int length, bool copy_string);
+  int get_port();
+  void set_port(HdrHeap *heap, unsigned int port);
+  void set_port(HdrHeap *heap, const char *value, int length, bool copy_string);
+  const char *get_path(int *length);
+  void set_path(HdrHeap *heap, const char *value, int length, bool copy_string);
+  int get_type();
+  void set_type(int type);
+  int get_type_code();
+  void set_type_code(unsigned int typecode);
+  const char *get_params(int *length);
+  void set_params(HdrHeap *heap, const char *value, int length, bool copy_string);
+  const char *get_query(int *length);
+  void set_query(HdrHeap *heap, const char *value, int length, bool copy_string);
+  const char *get_fragment(int *length);
+  void set_fragment(HdrHeap *heap, const char *value, int length, bool copy_string);
+
   // Marshaling Functions
   int marshal(MarshalXlate *str_xlate, int num_xlate);
   void unmarshal(intptr_t offset);
@@ -88,6 +115,8 @@ struct URLImpl : public HdrHeapObjImpl {
 
   // Sanity Check Functions
   void check_strings(HeapCheck *heaps, int num_heaps);
+
+private:
 };
 
 using URLHashContext = CryptoContext;
@@ -157,6 +186,8 @@ extern int URL_LEN_MMST;
 
 /* Public */
 bool validate_host_name(std::string_view addr);
+bool validate_scheme(std::string_view scheme);
+
 void url_init();
 
 URLImpl *url_create(HdrHeap *heap);
@@ -165,7 +196,6 @@ void url_nuke_proxy_stuff(URLImpl *d_url);
 
 URLImpl *url_copy(URLImpl *s_url, HdrHeap *s_heap, HdrHeap *d_heap, bool inherit_strs = true);
 void url_copy_onto(URLImpl *s_url, HdrHeap *s_heap, URLImpl *d_url, HdrHeap *d_heap, bool inherit_strs = true);
-void url_copy_onto_as_server_url(URLImpl *s_url, HdrHeap *s_heap, URLImpl *d_url, HdrHeap *d_heap, bool inherit_strs = true);
 
 // Normalization flag masks.
 namespace URLNormalize
@@ -188,23 +218,6 @@ char *url_string_get_buf(URLImpl *url, char *dstbuf, int dstbuf_size, int *lengt
 
 void url_CryptoHash_get(const URLImpl *url, CryptoHash *hash, cache_generation_t generation = -1);
 void url_host_CryptoHash_get(URLImpl *url, CryptoHash *hash);
-const char *url_scheme_set(HdrHeap *heap, URLImpl *url, const char *value, int value_wks_idx, int length, bool copy_string);
-
-/* Internet specific */
-void url_user_set(HdrHeap *heap, URLImpl *url, const char *value, int length, bool copy_string);
-void url_password_set(HdrHeap *heap, URLImpl *url, const char *value, int length, bool copy_string);
-void url_host_set(HdrHeap *heap, URLImpl *url, const char *value, int length, bool copy_string);
-void url_port_set(HdrHeap *heap, URLImpl *url, unsigned int port);
-
-/* HTTP specific */
-void url_path_set(HdrHeap *heap, URLImpl *url, const char *value, int length, bool copy_string);
-
-void url_type_set(URLImpl *url, unsigned int type);
-
-/* HTTP specific */
-void url_params_set(HdrHeap *heap, URLImpl *url, const char *value, int length, bool copy_string);
-void url_query_set(HdrHeap *heap, URLImpl *url, const char *value, int length, bool copy_string);
-void url_fragment_set(HdrHeap *heap, URLImpl *url, const char *value, int length, bool copy_string);
 
 constexpr bool USE_STRICT_URI_PARSING = true;
 
@@ -286,8 +299,8 @@ public:
   const char *path_get(int *length);
   void path_set(const char *value, int length);
 
-  int type_get();
-  void type_set(int type);
+  int type_code_get();
+  void type_code_set(int type);
 
   const char *params_get(int *length);
   void params_set(const char *value, int length);
@@ -502,13 +515,9 @@ inline const std::string_view
 URL::scheme_get()
 {
   ink_assert(valid());
-
-  if (m_url_impl->m_scheme_wks_idx >= 0) {
-    return std::string_view{hdrtoken_index_to_wks(m_url_impl->m_scheme_wks_idx),
-                            static_cast<size_t>(hdrtoken_index_to_length(m_url_impl->m_scheme_wks_idx))};
-  } else {
-    return std::string_view{m_url_impl->m_ptr_scheme, m_url_impl->m_len_scheme};
-  }
+  int length;
+  const char *scheme = m_url_impl->get_scheme(&length);
+  return std::string_view{scheme, static_cast<size_t>(length)};
 }
 
 inline const char *
@@ -534,7 +543,7 @@ URL::scheme_set(const char *value, int length)
 {
   ink_assert(valid());
   int scheme_wks_idx = (value ? hdrtoken_tokenize(value, length) : -1);
-  url_scheme_set(m_heap, m_url_impl, value, scheme_wks_idx, length, true);
+  m_url_impl->set_scheme(m_heap, value, scheme_wks_idx, length, true);
 }
 
 /*-------------------------------------------------------------------------
@@ -544,8 +553,7 @@ inline const char *
 URL::user_get(int *length)
 {
   ink_assert(valid());
-  *length = m_url_impl->m_len_user;
-  return m_url_impl->m_ptr_user;
+  return m_url_impl->get_user(length);
 }
 
 /*-------------------------------------------------------------------------
@@ -555,7 +563,7 @@ inline void
 URL::user_set(const char *value, int length)
 {
   ink_assert(valid());
-  url_user_set(m_heap, m_url_impl, value, length, true);
+  m_url_impl->set_user(m_heap, value, length, true);
 }
 
 /*-------------------------------------------------------------------------
@@ -565,8 +573,7 @@ inline const char *
 URL::password_get(int *length)
 {
   ink_assert(valid());
-  *length = m_url_impl->m_len_password;
-  return m_url_impl->m_ptr_password;
+  return m_url_impl->get_password(length);
 }
 
 /*-------------------------------------------------------------------------
@@ -576,7 +583,7 @@ inline void
 URL::password_set(const char *value, int length)
 {
   ink_assert(valid());
-  url_password_set(m_heap, m_url_impl, value, length, true);
+  m_url_impl->set_password(m_heap, value, length, true);
 }
 
 /*-------------------------------------------------------------------------
@@ -586,8 +593,7 @@ inline const char *
 URL::host_get(int *length)
 {
   ink_assert(valid());
-  *length = m_url_impl->m_len_host;
-  return m_url_impl->m_ptr_host;
+  return m_url_impl->get_host(length);
 }
 
 /*-------------------------------------------------------------------------
@@ -597,7 +603,7 @@ inline void
 URL::host_set(const char *value, int length)
 {
   ink_assert(valid());
-  url_host_set(m_heap, m_url_impl, value, length, true);
+  m_url_impl->set_host(m_heap, value, length, true);
 }
 
 /*-------------------------------------------------------------------------
@@ -607,7 +613,7 @@ inline int
 URL::port_get() const
 {
   ink_assert(valid());
-  return url_canonicalize_port(m_url_impl->m_url_type, m_url_impl->m_port);
+  return url_canonicalize_port(m_url_impl->get_type(), m_url_impl->get_port());
 }
 
 /*-------------------------------------------------------------------------
@@ -617,7 +623,7 @@ inline int
 URL::port_get_raw() const
 {
   ink_assert(valid());
-  return m_url_impl->m_port;
+  return m_url_impl->get_port();
 }
 
 /*-------------------------------------------------------------------------
@@ -627,7 +633,7 @@ inline void
 URL::port_set(int port)
 {
   ink_assert(valid());
-  url_port_set(m_heap, m_url_impl, port);
+  m_url_impl->set_port(m_heap, port);
 }
 
 /*-------------------------------------------------------------------------
@@ -637,8 +643,7 @@ inline const char *
 URL::path_get(int *length)
 {
   ink_assert(valid());
-  *length = m_url_impl->m_len_path;
-  return m_url_impl->m_ptr_path;
+  return m_url_impl->get_path(length);
 }
 
 /*-------------------------------------------------------------------------
@@ -648,27 +653,27 @@ inline void
 URL::path_set(const char *value, int length)
 {
   ink_assert(valid());
-  url_path_set(m_heap, m_url_impl, value, length, true);
+  m_url_impl->set_path(m_heap, value, length, true);
 }
 
 /*-------------------------------------------------------------------------
   -------------------------------------------------------------------------*/
 
 inline int
-URL::type_get()
+URL::type_code_get()
 {
   ink_assert(valid());
-  return m_url_impl->m_type_code;
+  return m_url_impl->get_type_code();
 }
 
 /*-------------------------------------------------------------------------
   -------------------------------------------------------------------------*/
 
 inline void
-URL::type_set(int type)
+URL::type_code_set(int typecode)
 {
   ink_assert(valid());
-  url_type_set(m_url_impl, type);
+  m_url_impl->set_type_code(typecode);
 }
 
 /*-------------------------------------------------------------------------
@@ -678,8 +683,7 @@ inline const char *
 URL::params_get(int *length)
 {
   ink_assert(valid());
-  *length = m_url_impl->m_len_params;
-  return m_url_impl->m_ptr_params;
+  return m_url_impl->get_params(length);
 }
 
 /*-------------------------------------------------------------------------
@@ -689,7 +693,7 @@ inline void
 URL::params_set(const char *value, int length)
 {
   ink_assert(valid());
-  url_params_set(m_heap, m_url_impl, value, length, true);
+  m_url_impl->set_params(m_heap, value, length, true);
 }
 
 /*-------------------------------------------------------------------------
@@ -699,8 +703,7 @@ inline const char *
 URL::query_get(int *length)
 {
   ink_assert(valid());
-  *length = m_url_impl->m_len_query;
-  return m_url_impl->m_ptr_query;
+  return m_url_impl->get_query(length);
 }
 
 /*-------------------------------------------------------------------------
@@ -710,7 +713,7 @@ inline void
 URL::query_set(const char *value, int length)
 {
   ink_assert(valid());
-  url_query_set(m_heap, m_url_impl, value, length, true);
+  m_url_impl->set_query(m_heap, value, length, true);
 }
 
 /*-------------------------------------------------------------------------
@@ -720,8 +723,7 @@ inline const char *
 URL::fragment_get(int *length)
 {
   ink_assert(valid());
-  *length = m_url_impl->m_len_fragment;
-  return m_url_impl->m_ptr_fragment;
+  return m_url_impl->get_fragment(length);
 }
 
 /*-------------------------------------------------------------------------
@@ -731,7 +733,7 @@ inline void
 URL::fragment_set(const char *value, int length)
 {
   ink_assert(valid());
-  url_fragment_set(m_heap, m_url_impl, value, length, true);
+  m_url_impl->set_fragment(m_heap, value, length, true);
 }
 
 /**
