@@ -33,7 +33,7 @@
   The HttpBodyFactory can build a message body for each response type.
   The user can create custom message body text for each type (stored
   in a text file directory), containing templates with space-holders for
-  variables which are inline-substituted with curent values.  The resulting
+  variables which are inline-substituted with current values.  The resulting
   body is dynamically allocated and returned.
 
   The major data types implemented in this file are:
@@ -61,10 +61,11 @@
 #include "HttpConfig.h"
 #include "HttpCompat.h"
 #include "HttpTransact.h"
-#include "Main.h"
-#include "tscore/RawHashTable.h"
 #include "tscore/ink_sprintf.h"
 
+#include <memory>
+#include <unordered_map>
+
 #define HTTP_BODY_TEMPLATE_MAGIC 0xB0DFAC00
 #define HTTP_BODY_SET_MAGIC 0xB0DFAC55
 #define HTTP_BODY_FACTORY_MAGIC 0xB0DFACFF
@@ -101,6 +102,23 @@ public:
   char *template_pathname;
 };
 
+////////////////////////////////////////////////////////////////////////
+//
+//      class HttpBodySetRawData
+//
+//      Raw data members of HttpBodySet
+//
+////////////////////////////////////////////////////////////////////////
+
+struct HttpBodySetRawData {
+  using TemplateTable = std::unordered_map<std::string, HttpBodyTemplate *>;
+  unsigned int magic  = 0;
+  char *set_name;
+  char *content_language;
+  char *content_charset;
+  std::unique_ptr<TemplateTable> table_of_pages;
+};
+
 ////////////////////////////////////////////////////////////////////////
 //
 //      class HttpBodySet
@@ -109,8 +127,7 @@ public:
 //      templates.  It includes operators to get the hash table of
 //      templates, and the associated metadata for the set.
 //
-//      The raw data members come from HttpBodySetRawData, which
-//      is defined in proxy/hdrs/HttpCompat.h
+//      The raw data members come from HttpBodySetRawData above
 //
 ////////////////////////////////////////////////////////////////////////
 
@@ -148,6 +165,7 @@ public:
 class HttpBodyFactory
 {
 public:
+  using BodySetTable = std::unordered_map<std::string, HttpBodySetRawData *>;
   HttpBodyFactory();
   ~HttpBodyFactory();
 
@@ -183,6 +201,11 @@ public:
 
   void dump_template_tables(FILE *fp = stderr);
   void reconfigure();
+  static const char *determine_set_by_language(std::unique_ptr<BodySetTable> &table_of_sets, StrList *acpt_language_list,
+                                               StrList *acpt_charset_list, float *Q_best_ptr, int *La_best_ptr, int *Lc_best_ptr,
+                                               int *I_best_ptr);
+
+  bool is_response_suppressed(HttpTransact::State *context);
 
 private:
   char *fabricate(StrList *acpt_language_list, StrList *acpt_charset_list, const char *type, HttpTransact::State *context,
@@ -192,7 +215,6 @@ private:
   const char *determine_set_by_language(StrList *acpt_language_list, StrList *acpt_charset_list);
   const char *determine_set_by_host(HttpTransact::State *context);
   HttpBodyTemplate *find_template(const char *set, const char *type, HttpBodySet **body_set_return);
-  bool is_response_suppressed(HttpTransact::State *context);
   bool
   is_sane()
   {
@@ -209,7 +231,7 @@ private:
   // initialization methods //
   ////////////////////////////
   void nuke_template_tables();
-  RawHashTable *load_sets_from_directory(char *set_dir);
+  std::unique_ptr<BodySetTable> load_sets_from_directory(char *set_dir);
   HttpBodySet *load_body_set_from_directory(char *set_name, char *tmpl_dir);
 
   /////////////////////////////////////////////////
@@ -229,15 +251,14 @@ private:
   /////////////////////////////////////
   // manager configuration variables //
   /////////////////////////////////////
-  int enable_customizations     = 0;    // 0:no custom,1:custom,2:language-targeted
-  bool enable_logging           = true; // the user wants body factory logging
-  int response_suppression_mode = 0;    // when to suppress responses
+  int enable_customizations = 0;    // 0:no custom,1:custom,2:language-targeted
+  bool enable_logging       = true; // the user wants body factory logging
 
   ////////////////////
   // internal state //
   ////////////////////
   unsigned int magic = HTTP_BODY_FACTORY_MAGIC; // magic for sanity checks/debugging
   ink_mutex mutex;                              // prevents reconfig/read races
-  bool callbacks_established  = false;          // all config variables present
-  RawHashTable *table_of_sets = nullptr;        // sets of template hash tables
+  bool callbacks_established = false;           // all config variables present
+  std::unique_ptr<BodySetTable> table_of_sets;  // sets of template hash tables
 };
