@@ -41,22 +41,10 @@
 #include "UrlRewrite.h"
 #include "HttpTunnel.h"
 #include "InkAPIInternal.h"
-#include "../ProxyClientTransaction.h"
+#include "../ProxyTransaction.h"
 #include "HdrUtils.h"
 #include "tscore/History.h"
-
-/* Enable LAZY_BUF_ALLOC to delay allocation of buffers until they
- * are actually required.
- * Enabling LAZY_BUF_ALLOC, stop Http code from allocation space
- * for header buffer and tunnel buffer. The allocation is done by
- * the net code in read_from_net when data is actually written into
- * the buffer. By allocating memory only when it is required we can
- * reduce the memory consumed by TS process.
- *
- * IMPORTANT NOTE: enable/disable LAZY_BUF_ALLOC in HttpServerSession.h
- * as well.
- */
-#define LAZY_BUF_ALLOC
+#include "tscore/PendingAction.h"
 
 #define HTTP_API_CONTINUE (INK_API_EVENT_EVENTS_START + 0)
 #define HTTP_API_ERROR (INK_API_EVENT_EVENTS_START + 1)
@@ -72,8 +60,9 @@ static size_t const HTTP_HEADER_BUFFER_SIZE_INDEX = CLIENT_CONNECTION_FIRST_READ
 //   the larger buffer size
 static size_t const HTTP_SERVER_RESP_HDR_BUFFER_INDEX = BUFFER_SIZE_INDEX_8K;
 
-class HttpServerSession;
+class Http1ServerSession;
 class AuthHttpAdapter;
+class PreWarmSM;
 
 class HttpSM;
 typedef int (HttpSM::*HttpSMHandler)(int event, void *data);
@@ -105,13 +94,14 @@ struct HttpVCTableEntry {
   VIO *write_vio;
   HttpSMHandler vc_handler;
   HttpVC_t vc_type;
+  HttpSM *sm;
   bool eos;
   bool in_tunnel;
 };
 
 struct HttpVCTable {
   static const int vc_table_max_entries = 4;
-  HttpVCTable();
+  explicit HttpVCTable(HttpSM *);
 
   HttpVCTableEntry *new_entry();
   HttpVCTableEntry *find_entry(VConnection *);
@@ -123,6 +113,7 @@ struct HttpVCTable {
 
 private:
   HttpVCTableEntry vc_table[vc_table_max_entries];
+  HttpSM *sm = nullptr;
 };
 
 inline bool
@@ -137,10 +128,10 @@ HttpVCTable::is_table_clear() const
 }
 
 struct HttpTransformInfo {
-  HttpVCTableEntry *entry;
-  VConnection *vc;
+  HttpVCTableEntry *entry = nullptr;
+  VConnection *vc         = nullptr;
 
-  HttpTransformInfo() : entry(nullptr), vc(nullptr) {}
+  HttpTransformInfo() {}
 };
 
 enum {
@@ -166,6 +157,7 @@ enum HttpApiState_t {
   HTTP_API_IN_CALLOUT,
   HTTP_API_DEFERED_CLOSE,
   HTTP_API_DEFERED_SERVER_ERROR,
+  HTTP_API_REWIND_STATE_MACHINE,
 };
 
 enum HttpPluginTunnel_t {
@@ -174,7 +166,6 @@ enum HttpPluginTunnel_t {
   HTTP_PLUGIN_AS_INTERCEPT,
 };
 
-class CoreUtils;
 class PluginVCCore;
 
 class PostDataBuffers
@@ -209,10 +200,10 @@ public:
   ~PostDataBuffers();
 };
 
-class HttpSM : public Continuation
+class HttpSM : public Continuation, public PluginUserArgs<TS_USER_ARGS_TXN>
 {
   friend class HttpPagesHandler;
-  friend class CoreUtils;
+  friend class HttpTransact;
 
 public:
   HttpSM();
@@ -220,31 +211,37 @@ public:
   virtual void destroy();
 
   static HttpSM *allocate();
-  HttpCacheSM &get_cache_sm();      // Added to get the object of CacheSM YTS Team, yamsat
-  HttpVCTableEntry *get_ua_entry(); // Added to get the ua_entry pointer  - YTS-TEAM
+  HttpCacheSM &get_cache_sm(); // Added to get the object of CacheSM YTS Team, yamsat
+  std::string_view get_outbound_sni() const;
+  std::string_view get_outbound_cert() const;
 
-  void init();
+  void init(bool from_early_data = false);
 
-  void attach_client_session(ProxyClientTransaction *client_vc_arg, IOBufferReader *buffer_reader);
+  void attach_client_session(ProxyTransaction *client_vc_arg);
 
-  // Called by httpSessionManager so that we can reset
-  //  the session timeouts and initiate a read while
+  // Called after the network connection has been completed
+  //  to set the session timeouts and initiate a read while
   //  holding the lock for the server session
-  void attach_server_session(HttpServerSession *s);
+  void attach_server_session();
 
-  // Used to read attributes of
-  // the current active server session
-  HttpServerSession *
-  get_server_session()
-  {
-    return server_session;
-  }
+  PoolableSession *create_server_session(NetVConnection *netvc);
+  bool create_server_txn(PoolableSession *new_session);
+
+  HTTPVersion get_server_version(HTTPHdr &hdr) const;
+
+  ProxyTransaction *get_ua_txn();
+  ProxyTransaction *get_server_txn();
 
   // Called by transact.  Updates are fire and forget
   //  so there are no callbacks and are safe to do
   //  directly from transact
   void do_hostdb_update_if_necessary();
 
+  // Look at the configured policy and the current server connect_result
+  // to determine whether this connection attempt should contribute to the
+  // dead server count
+  bool track_connect_fail() const;
+
   // Called by transact. Decide if cached response supports Range and
   // setup Range transfomration if so.
   // return true when the Range is unsatisfiable
@@ -270,13 +267,9 @@ public:
   VConnection *do_transform_open();
   VConnection *do_post_transform_open();
 
-  // Called by transact(HttpTransact::is_request_retryable), temperarily.
+  // Called by transact(HttpTransact::is_request_retryable), temporarily.
   // This function should be remove after #1994 fixed.
-  bool
-  is_post_transform_request()
-  {
-    return t_state.method == HTTP_WKSIDX_POST && post_transform_info.vc;
-  }
+  bool is_post_transform_request();
 
   // Called from InkAPI.cc which acquires the state machine lock
   //  before calling
@@ -284,19 +277,14 @@ public:
   int state_api_callout(int event, void *data);
 
   // Used for Http Stat Pages
-  HttpTunnel *
-  get_tunnel()
-  {
-    return &tunnel;
-  }
+  HttpTunnel *get_tunnel();
 
   // Debugging routines to dump the SM history, hdrs
   void dump_state_on_assert();
   void dump_state_hdr(HTTPHdr *h, const char *s);
 
   // Functions for manipulating api hooks
-  void txn_hook_append(TSHttpHookID id, INKContInternal *cont);
-  void txn_hook_prepend(TSHttpHookID id, INKContInternal *cont);
+  void txn_hook_add(TSHttpHookID id, INKContInternal *cont);
   APIHook *txn_hook_get(TSHttpHookID id);
 
   bool is_private();
@@ -307,6 +295,13 @@ public:
   /// @arg n [in] Size of the array @a result.
   int populate_client_protocol(std::string_view *result, int n) const;
   const char *client_protocol_contains(std::string_view tag_prefix) const;
+
+  /// Get the protocol stack for the outbound (origin server) connection.
+  /// @arg result [out] Array to store the results
+  /// @arg n [in] Size of the array @a result.
+  int populate_server_protocol(std::string_view *result, int n) const;
+  const char *server_protocol_contains(std::string_view tag_prefix) const;
+
   std::string_view find_proto_string(HTTPVersion version) const;
 
   int64_t sm_id      = -1;
@@ -327,7 +322,7 @@ public:
 
   HttpTransact::State t_state;
 
-  // This unfortunately can't go into the t_state, beacuse of circular dependencies. We could perhaps refactor
+  // This unfortunately can't go into the t_state, because of circular dependencies. We could perhaps refactor
   // this, with a lot of work, but this is easier for now.
   UrlRewrite *m_remap = nullptr;
 
@@ -343,6 +338,11 @@ public:
   bool get_postbuf_done();
   bool is_postbuf_valid();
 
+  // See if we should allow the transaction
+  // based on sni and host name header values
+  void check_sni_host();
+  SNIRoutingType get_tunnel_type() const;
+
 protected:
   int reentrancy_count = 0;
 
@@ -350,34 +350,28 @@ protected:
 
   HttpVCTable vc_table;
 
-  HttpVCTableEntry *ua_entry = nullptr;
-  void remove_ua_entry();
-
 public:
-  ProxyClientTransaction *ua_txn   = nullptr;
   BackgroundFill_t background_fill = BACKGROUND_FILL_NONE;
-  // AuthHttpAdapter authAdapter;
   void set_http_schedule(Continuation *);
   int get_http_schedule(int event, void *data);
 
   History<HISTORY_DEFAULT_SIZE> history;
 
+  ProxyTransaction *ua_txn = nullptr;
+
 protected:
-  IOBufferReader *ua_buffer_reader     = nullptr;
   IOBufferReader *ua_raw_buffer_reader = nullptr;
 
-  HttpVCTableEntry *server_entry    = nullptr;
-  HttpServerSession *server_session = nullptr;
+  HttpVCTableEntry *ua_entry     = nullptr;
+  HttpVCTableEntry *server_entry = nullptr;
+  ProxyTransaction *server_txn   = nullptr;
 
   /* Because we don't want to take a session from a shared pool if we know that it will be private,
    * but we cannot set it to private until we have an attached server session.
    * So we use this variable to indicate that
    * we should create a new connection and then once we attach the session we'll mark it as private.
    */
-  bool will_be_private_ss              = false;
-  int shared_session_retries           = 0;
-  IOBufferReader *server_buffer_reader = nullptr;
-  void remove_server_entry();
+  bool will_be_private_ss = false;
 
   HttpTransformInfo transform_info;
   HttpTransformInfo post_transform_info;
@@ -410,7 +404,6 @@ protected:
   int state_read_client_request_header(int event, void *data);
   int state_watch_for_client_abort(int event, void *data);
   int state_read_push_response_header(int event, void *data);
-  int state_srv_lookup(int event, void *data);
   int state_hostdb_lookup(int event, void *data);
   int state_hostdb_reverse_lookup(int event, void *data);
   int state_mark_os_down(int event, void *data);
@@ -466,11 +459,11 @@ protected:
   void do_cache_prepare_action(HttpCacheSM *c_sm, CacheHTTPInfo *object_read_info, bool retry, bool allow_multiple = false);
   void do_cache_delete_all_alts(Continuation *cont);
   void do_auth_callout();
-  void do_api_callout();
-  void do_api_callout_internal();
+  int do_api_callout();
+  int do_api_callout_internal();
   void do_redirect();
   void redirect_request(const char *redirect_url, const int redirect_len);
-  void do_drain_request_body();
+  void do_drain_request_body(HTTPHdr &response);
 
   void wait_for_full_body();
 
@@ -479,13 +472,11 @@ protected:
   void handle_http_server_open();
   void handle_post_failure();
   void mark_host_failure(HostDBInfo *info, time_t time_down);
-  void mark_server_down_on_client_abort();
   void release_server_session(bool serve_from_cache = false);
   void set_ua_abort(HttpTransact::AbortState_t ua_abort, int event);
   int write_header_into_buffer(HTTPHdr *h, MIOBuffer *b);
   int write_response_header_into_buffer(HTTPHdr *h, MIOBuffer *b);
   void setup_blind_tunnel_port();
-  void setup_client_header_nca();
   void setup_client_read_request_header();
   void setup_push_read_response_header();
   void setup_server_read_response_header();
@@ -505,13 +496,20 @@ protected:
   void issue_cache_update();
   void perform_cache_write_action();
   void perform_transform_cache_write_action();
-  void perform_nca_cache_action();
   void setup_blind_tunnel(bool send_response_hdr, IOBufferReader *initial = nullptr);
   HttpTunnelProducer *setup_server_transfer_to_transform();
   HttpTunnelProducer *setup_transfer_from_transform();
   HttpTunnelProducer *setup_cache_transfer_to_transform();
   HttpTunnelProducer *setup_transfer_from_transform_to_cache_only();
-  void setup_plugin_agents(HttpTunnelProducer *p);
+
+  /** Configure consumers for transform plugins.
+   *
+   * @param[in] p The Tunnel's producer for whom transform plugins' consumers
+   *   will be configured.
+   * @param[in] num_header_bytes The number of header bytes in the stream.
+   *   These will be skipped and not passed to the consumers of the data sink.
+   */
+  void setup_plugin_agents(HttpTunnelProducer *p, int num_header_bytes);
 
   HttpTransact::StateMachineAction_t last_action     = HttpTransact::SM_ACTION_UNDEFINED;
   int (HttpSM::*m_last_state)(int event, void *data) = nullptr;
@@ -524,32 +522,40 @@ protected:
   int find_http_resp_buffer_size(int64_t cl);
   int64_t server_transfer_init(MIOBuffer *buf, int hdr_size);
 
+  /// Update the milestones to track time spent in the plugin API.
+  void milestone_update_api_time();
+
 public:
   // TODO:  Now that bodies can be empty, should the body counters be set to -1 ? TS-2213
   // Stats & Logging Info
-  int client_request_hdr_bytes       = 0;
-  int64_t client_request_body_bytes  = 0;
-  int server_request_hdr_bytes       = 0;
-  int64_t server_request_body_bytes  = 0;
-  int server_response_hdr_bytes      = 0;
-  int64_t server_response_body_bytes = 0;
-  int client_response_hdr_bytes      = 0;
-  int64_t client_response_body_bytes = 0;
-  int cache_response_hdr_bytes       = 0;
-  int64_t cache_response_body_bytes  = 0;
-  int pushed_response_hdr_bytes      = 0;
-  int64_t pushed_response_body_bytes = 0;
-  bool client_tcp_reused             = false;
-  bool client_ssl_reused             = false;
-  bool client_connection_is_ssl      = false;
-  bool is_internal                   = false;
-  bool server_connection_is_ssl      = false;
-  bool is_waiting_for_full_body      = false;
-  bool is_using_post_buffer          = false;
+  int client_request_hdr_bytes        = 0;
+  int64_t client_request_body_bytes   = 0;
+  int server_request_hdr_bytes        = 0;
+  int64_t server_request_body_bytes   = 0;
+  int server_response_hdr_bytes       = 0;
+  int64_t server_response_body_bytes  = 0;
+  int client_response_hdr_bytes       = 0;
+  int64_t client_response_body_bytes  = 0;
+  int cache_response_hdr_bytes        = 0;
+  int64_t cache_response_body_bytes   = 0;
+  int pushed_response_hdr_bytes       = 0;
+  int64_t pushed_response_body_bytes  = 0;
+  int server_connection_provided_cert = 0;
+  bool client_tcp_reused              = false;
+  bool client_ssl_reused              = false;
+  bool client_connection_is_ssl       = false;
+  bool is_internal                    = false;
+  bool server_ssl_reused              = false;
+  bool server_connection_is_ssl       = false;
+  bool is_waiting_for_full_body       = false;
+  bool is_using_post_buffer           = false;
   std::optional<bool> mptcp_state; // Don't initialize, that marks it as "not defined".
   const char *client_protocol     = "-";
+  const char *server_protocol     = "-";
   const char *client_sec_protocol = "-";
   const char *client_cipher_suite = "-";
+  const char *client_curve        = "-";
+  int client_alpn_id              = SessionProtocolNameRegistry::INVALID;
   int server_transact_count       = 0;
 
   TransactionMilestones milestones;
@@ -567,7 +573,8 @@ public:
 
 protected:
   TSHttpHookID cur_hook_id = TS_HTTP_LAST_HOOK;
-  APIHook *cur_hook        = nullptr;
+  APIHook const *cur_hook  = nullptr;
+  HttpHookState hook_state;
 
   //
   // Continuation time keeper
@@ -587,7 +594,6 @@ protected:
   bool terminate_sm         = false;
   bool kill_this_async_done = false;
   bool parse_range_done     = false;
-  virtual int kill_this_async_hook(int event, void *data);
   void kill_this();
   void update_stats();
   void transform_cleanup(TSHttpHookID hook, HttpTransformInfo *info);
@@ -599,42 +605,84 @@ public:
 
 public:
   bool set_server_session_private(bool private_session);
-  bool
-  is_dying() const
-  {
-    return terminate_sm;
-  }
+  bool is_dying() const;
 
-  int
-  client_connection_id() const
-  {
-    return _client_connection_id;
-  }
+  int client_connection_id() const;
+  int client_transaction_id() const;
+  int client_transaction_priority_weight() const;
+  int client_transaction_priority_dependence() const;
 
-  int
-  client_transaction_id() const
-  {
-    return _client_transaction_id;
-  }
-
-  int
-  client_transaction_priority_weight() const
-  {
-    return _client_transaction_priority_weight;
-  }
-
-  int
-  client_transaction_priority_dependence() const
-  {
-    return _client_transaction_priority_dependence;
-  }
+  ink_hrtime get_server_inactivity_timeout();
+  ink_hrtime get_server_active_timeout();
+  ink_hrtime get_server_connect_timeout();
+  void rewind_state_machine();
 
 private:
   PostDataBuffers _postbuf;
   int _client_connection_id = -1, _client_transaction_id = -1;
   int _client_transaction_priority_weight = -1, _client_transaction_priority_dependence = -1;
+  bool _from_early_data       = false;
+  SNIRoutingType _tunnel_type = SNIRoutingType::NONE;
+  PreWarmSM *_prewarm_sm      = nullptr;
 };
 
+////
+// Inline Functions
+//
+inline ProxyTransaction *
+HttpSM::get_ua_txn()
+{
+  return ua_txn;
+}
+
+inline ProxyTransaction *
+HttpSM::get_server_txn()
+{
+  return server_txn;
+}
+
+inline bool
+HttpSM::is_post_transform_request()
+{
+  return t_state.method == HTTP_WKSIDX_POST && post_transform_info.vc;
+}
+
+inline HttpTunnel *
+HttpSM::get_tunnel()
+{
+  return &tunnel;
+}
+
+inline bool
+HttpSM::is_dying() const
+{
+  return terminate_sm;
+}
+
+inline int
+HttpSM::client_connection_id() const
+{
+  return _client_connection_id;
+}
+
+inline int
+HttpSM::client_transaction_id() const
+{
+  return _client_transaction_id;
+}
+
+inline int
+HttpSM::client_transaction_priority_weight() const
+{
+  return _client_transaction_priority_weight;
+}
+
+inline int
+HttpSM::client_transaction_priority_dependence() const
+{
+  return _client_transaction_priority_dependence;
+}
+
 // Function to get the cache_sm object - YTS Team, yamsat
 inline HttpCacheSM &
 HttpSM::get_cache_sm()
@@ -642,36 +690,6 @@ HttpSM::get_cache_sm()
   return cache_sm;
 }
 
-// Function to get the ua_entry pointer - YTS Team, yamsat
-inline HttpVCTableEntry *
-HttpSM::get_ua_entry()
-{
-  return ua_entry;
-}
-
-inline HttpSM *
-HttpSM::allocate()
-{
-  extern ClassAllocator<HttpSM> httpSMAllocator;
-  return httpSMAllocator.alloc();
-}
-
-inline void
-HttpSM::remove_ua_entry()
-{
-  vc_table.remove_entry(ua_entry);
-  ua_entry = nullptr;
-}
-
-inline void
-HttpSM::remove_server_entry()
-{
-  if (server_entry) {
-    vc_table.remove_entry(server_entry);
-    server_entry = nullptr;
-  }
-}
-
 inline int
 HttpSM::write_response_header_into_buffer(HTTPHdr *h, MIOBuffer *b)
 {
@@ -689,19 +707,12 @@ HttpSM::find_server_buffer_size()
 }
 
 inline void
-HttpSM::txn_hook_append(TSHttpHookID id, INKContInternal *cont)
+HttpSM::txn_hook_add(TSHttpHookID id, INKContInternal *cont)
 {
   api_hooks.append(id, cont);
   hooks_set = true;
 }
 
-inline void
-HttpSM::txn_hook_prepend(TSHttpHookID id, INKContInternal *cont)
-{
-  api_hooks.prepend(id, cont);
-  hooks_set = true;
-}
-
 inline APIHook *
 HttpSM::txn_hook_get(TSHttpHookID id)
 {
@@ -711,7 +722,7 @@ HttpSM::txn_hook_get(TSHttpHookID id)
 inline bool
 HttpSM::is_transparent_passthrough_allowed()
 {
-  return (t_state.client_info.is_transparent && ua_txn->is_transparent_passthrough_allowed() && ua_txn->get_transact_count() == 1);
+  return (t_state.client_info.is_transparent && ua_txn->is_transparent_passthrough_allowed() && ua_txn->is_first_transaction());
 }
 
 inline int64_t
