@@ -29,6 +29,6 @@ class Http3FrameGenerator
 {
 public:
   virtual ~Http3FrameGenerator(){};
-  virtual Http3FrameUPtr generate_frame(uint16_t max_size) = 0;
-  virtual bool is_done() const                             = 0;
+  virtual Http3FrameUPtr generate_frame() = 0;
+  virtual bool is_done() const            = 0;
 };
