@@ -28,25 +28,21 @@
 #include "tscore/ink_memory.h"
 #include "tscore/Regex.h"
 
-#if defined(PCRE_CONFIG_JIT) && !defined(darwin) // issue with macOS Catalina and pcre 8.43
-struct RegexThreadKey {
-  RegexThreadKey() { ink_thread_key_create(&this->key, reinterpret_cast<void (*)(void *)>(&pcre_jit_stack_free)); }
-  ink_thread_key key;
-};
-
-static RegexThreadKey k;
-
+#ifdef PCRE_CONFIG_JIT
 static pcre_jit_stack *
 get_jit_stack(void *data ATS_UNUSED)
 {
-  pcre_jit_stack *jit_stack;
+  thread_local struct JitStack {
+    JitStack()
+    {
+      jit_stack = pcre_jit_stack_alloc(ats_pagesize(), 1024 * 1024); // 1 page min and 1MB max
+    }
+    ~JitStack() { pcre_jit_stack_free(jit_stack); }
 
-  if ((jit_stack = static_cast<pcre_jit_stack *>(ink_thread_getspecific(k.key))) == nullptr) {
-    jit_stack = pcre_jit_stack_alloc(ats_pagesize(), 1024 * 1024); // 1 page min and 1MB max
-    ink_thread_setspecific(k.key, (void *)jit_stack);
-  }
+    pcre_jit_stack *jit_stack = nullptr;
+  } stack;
 
-  return jit_stack;
+  return stack.jit_stack;
 }
 #endif
 
@@ -82,13 +78,13 @@ Regex::compile(const char *pattern, const unsigned flags)
     return false;
   }
 
-#if defined(PCRE_CONFIG_JIT) && !defined(darwin) // issue with macOS Catalina and pcre 8.43
+#ifdef PCRE_CONFIG_JIT
   study_opts |= PCRE_STUDY_JIT_COMPILE;
 #endif
 
   regex_extra = pcre_study(regex, study_opts, &error);
 
-#if defined(PCRE_CONFIG_JIT) && !defined(darwin) // issue with macOS Catalina and pcre 8.43
+#ifdef PCRE_CONFIG_JIT
   if (regex_extra) {
     pcre_assign_jit_stack(regex_extra, &get_jit_stack, nullptr);
   }
@@ -127,7 +123,7 @@ Regex::exec(std::string_view const &str, int *ovector, int ovecsize) const
 Regex::~Regex()
 {
   if (regex_extra) {
-#if defined(PCRE_CONFIG_JIT) && !defined(darwin) // issue with macOS Catalina and pcre 8.43
+#ifdef PCRE_CONFIG_JIT
     pcre_free_study(regex_extra);
 #else
     pcre_free(regex_extra);
