@@ -30,11 +30,6 @@ class Foo
 public:
   int x;
 
-  void
-  foo()
-  {
-  }
-
   SLINK(Foo, slink);
   LINK(Foo, dlink);
 
