@@ -28,9 +28,7 @@ ts = Test.MakeATSProcess("ts")
 HOST = 'www.connectfail502.test'
 server = Test.MakeOriginServer("server", ssl=False)  # Reserves a port across autest.
 
-ts.Disk.remap_config.AddLine(
-    'map http://{host} http://{ip}:{uport}'.format(host=HOST, ip='127.0.0.1', uport=server.Variables.Port)
-)
+ts.Disk.remap_config.AddLine('map http://{host} http://{ip}:{uport}'.format(host=HOST, ip='127.0.0.1', uport=server.Variables.Port))
 
 Test.Setup.Copy(os.path.join(Test.Variables.AtsTestToolsDir, 'tcp_client.py'))
 
@@ -42,6 +40,6 @@ tr.Processes.Default.StartBefore(Test.Processes.ts)
 # Do not start the origin server: We wish to simulate connection refused while hopefully no one else uses this port.
 tr.Processes.Default.Command = \
     (f"{sys.executable} tcp_client.py 127.0.0.1 {ts.Variables.port} www.connectfail502.test-get.txt | "
-     "sed -e '/^Date: /d' -e '/^Server: ATS\//d'")
+     r"sed -e '/^Date: /d' -e '/^Server: ATS\//d'")
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = 'general-connection-failure-502.gold'
