@@ -22,9 +22,7 @@ Test.Summary = '''
 Test the Multiplexer plugin.
 '''
 
-Test.SkipUnless(
-    Condition.PluginExists('multiplexer.so')
-)
+Test.SkipUnless(Condition.PluginExists('multiplexer.so'))
 
 
 class MultiplexerTestBase:
@@ -46,92 +44,74 @@ class MultiplexerTestBase:
     def setupServers(self):
         counter = MultiplexerTestBase.server_counter
         MultiplexerTestBase.server_counter += 1
-        self.server_origin = Test.MakeVerifierServerProcess(
-            f"server_origin_{counter}", self.replay_file)
-        self.server_http = Test.MakeVerifierServerProcess(
-            f"server_http_{counter}", self.multiplexed_host_replay_file)
-        self.server_https = Test.MakeVerifierServerProcess(
-            f"server_https_{counter}", self.multiplexed_host_replay_file)
+        self.server_origin = Test.MakeVerifierServerProcess(f"server_origin_{counter}", self.replay_file)
+        self.server_http = Test.MakeVerifierServerProcess(f"server_http_{counter}", self.multiplexed_host_replay_file)
+        self.server_https = Test.MakeVerifierServerProcess(f"server_https_{counter}", self.multiplexed_host_replay_file)
 
         # The origin should never receive "X-Multiplexer: copy"
         self.server_origin.Streams.All += Testers.ExcludesExpression(
-            'X-Multiplexer: copy',
-            'Verify the original server target never receives a "copy".')
+            'X-Multiplexer: copy', 'Verify the original server target never receives a "copy".')
 
         # Nor should the multiplexed hosts receive an "original" X-Multiplexer value.
         self.server_http.Streams.All += Testers.ExcludesExpression(
-            'X-Multiplexer: original',
-            'Verify the HTTP multiplexed host does not receive an "original".')
+            'X-Multiplexer: original', 'Verify the HTTP multiplexed host does not receive an "original".')
         self.server_https.Streams.All += Testers.ExcludesExpression(
-            'X-Multiplexer: original',
-            'Verify the HTTPS multiplexed host does not receive an "original".')
+            'X-Multiplexer: original', 'Verify the HTTPS multiplexed host does not receive an "original".')
 
         # In addition, the original server should always receive the POST and
         # PUT requests.
         self.server_origin.Streams.All += Testers.ContainsExpression(
-            'uuid: POST',
-            "Verify the client's original target received the POST transaction.")
+            'uuid: POST', "Verify the client's original target received the POST transaction.")
         self.server_origin.Streams.All += Testers.ContainsExpression(
-            'uuid: PUT',
-            "Verify the client's original target received the PUT transaction.")
+            'uuid: PUT', "Verify the client's original target received the PUT transaction.")
 
         # Under all configurations, the GET request should be multiplexed.
         self.server_origin.Streams.All += Testers.ContainsExpression(
-            'X-Multiplexer: original',
-            'Verify the client\'s original target received the "original" request.')
+            'X-Multiplexer: original', 'Verify the client\'s original target received the "original" request.')
         self.server_origin.Streams.All += Testers.ContainsExpression(
-            'uuid: GET',
-            "Verify the client's original target received the GET request.")
+            'uuid: GET', "Verify the client's original target received the GET request.")
 
         self.server_http.Streams.All += Testers.ContainsExpression(
-            'X-Multiplexer: copy',
-            'Verify the HTTP server received a "copy" of the request.')
-        self.server_http.Streams.All += Testers.ContainsExpression(
-            'uuid: GET',
-            "Verify the HTTP server received the GET request.")
+            'X-Multiplexer: copy', 'Verify the HTTP server received a "copy" of the request.')
+        self.server_http.Streams.All += Testers.ContainsExpression('uuid: GET', "Verify the HTTP server received the GET request.")
 
         self.server_https.Streams.All += Testers.ContainsExpression(
-            'X-Multiplexer: copy',
-            'Verify the HTTPS server received a "copy" of the request.')
+            'X-Multiplexer: copy', 'Verify the HTTPS server received a "copy" of the request.')
         self.server_https.Streams.All += Testers.ContainsExpression(
-            'uuid: GET',
-            "Verify the HTTPS server received the GET request.")
+            'uuid: GET', "Verify the HTTPS server received the GET request.")
 
         # Verify that the HTTPS server receives a TLS connection.
         self.server_https.Streams.All += Testers.ContainsExpression(
-            'Finished accept using TLSSession',
-            "Verify the HTTPS was indeed used by the HTTPS server.")
+            'Finished accept using TLSSession', "Verify the HTTPS was indeed used by the HTTPS server.")
 
     def setupTS(self, skip_post):
         counter = MultiplexerTestBase.ts_counter
         MultiplexerTestBase.ts_counter += 1
         self.ts = Test.MakeATSProcess(f"ts_{counter}", enable_tls=True, enable_cache=False)
         self.ts.addDefaultSSLFiles()
-        self.ts.Disk.records_config.update({
-            "proxy.config.ssl.server.cert.path": f'{self.ts.Variables.SSLDir}',
-            "proxy.config.ssl.server.private_key.path": f'{self.ts.Variables.SSLDir}',
-            "proxy.config.ssl.client.verify.server.policy": 'PERMISSIVE',
-            'proxy.config.ssl.keylog_file': '/tmp/tls_session_keys.txt',
-
-            'proxy.config.diags.debug.enabled': 1,
-            'proxy.config.diags.debug.tags': 'multiplexer',
-        })
-        self.ts.Disk.ssl_multicert_config.AddLine(
-            'dest_ip=* ssl_cert_name=server.pem ssl_key_name=server.key'
-        )
+        self.ts.Disk.records_config.update(
+            {
+                "proxy.config.ssl.server.cert.path": f'{self.ts.Variables.SSLDir}',
+                "proxy.config.ssl.server.private_key.path": f'{self.ts.Variables.SSLDir}',
+                "proxy.config.ssl.client.verify.server.policy": 'PERMISSIVE',
+                'proxy.config.diags.debug.enabled': 1,
+                'proxy.config.diags.debug.tags': 'multiplexer',
+            })
+        self.ts.Disk.ssl_multicert_config.AddLine('dest_ip=* ssl_cert_name=server.pem ssl_key_name=server.key')
         skip_remap_param = ''
         if skip_post:
             skip_remap_param = ' @pparam=proxy.config.multiplexer.skip_post_put=1'
-        self.ts.Disk.remap_config.AddLines([
-            f'map https://origin.server.com https://127.0.0.1:{self.server_origin.Variables.https_port} '
-            f'@plugin=multiplexer.so @pparam=nontls.server.com @pparam=tls.server.com'
-            f'{skip_remap_param}',
+        self.ts.Disk.remap_config.AddLines(
+            [
+                f'map https://origin.server.com https://127.0.0.1:{self.server_origin.Variables.https_port} '
+                f'@plugin=multiplexer.so @pparam=nontls.server.com @pparam=tls.server.com'
+                f'{skip_remap_param}',
 
-            # Now create remap entries for the multiplexed hosts: one that
-            # verifies HTTP, and another that verifies HTTPS.
-            f'map http://nontls.server.com http://127.0.0.1:{self.server_http.Variables.http_port}',
-            f'map http://tls.server.com https://127.0.0.1:{self.server_https.Variables.https_port}',
-        ])
+                # Now create remap entries for the multiplexed hosts: one that
+                # verifies HTTP, and another that verifies HTTPS.
+                f'map http://nontls.server.com http://127.0.0.1:{self.server_http.Variables.http_port}',
+                f'map http://tls.server.com https://127.0.0.1:{self.server_https.Variables.https_port}',
+            ])
 
     def run(self):
         tr = Test.AddTestRun()
@@ -142,10 +122,7 @@ class MultiplexerTestBase:
 
         counter = MultiplexerTestBase.client_counter
         MultiplexerTestBase.client_counter += 1
-        tr.AddVerifierClientProcess(
-            f"client_{counter}",
-            self.replay_file,
-            https_ports=[self.ts.Variables.ssl_port])
+        tr.AddVerifierClientProcess(f"client_{counter}", self.replay_file, https_ports=[self.ts.Variables.ssl_port])
 
 
 class MultiplexerTest(MultiplexerTestBase):
@@ -157,10 +134,7 @@ class MultiplexerTest(MultiplexerTestBase):
     multiplexed_host_replay_file = os.path.join("replays", "multiplexer_copy.replay.yaml")
 
     def __init__(self):
-        super().__init__(
-            MultiplexerTest.replay_file,
-            MultiplexerTest.multiplexed_host_replay_file,
-            skip_post=False)
+        super().__init__(MultiplexerTest.replay_file, MultiplexerTest.multiplexed_host_replay_file, skip_post=False)
 
     def setupServers(self):
         super().setupServers()
@@ -168,19 +142,14 @@ class MultiplexerTest(MultiplexerTestBase):
         # Both of the multiplexed hosts should receive the POST because skip_post
         # is disabled.
         self.server_http.Streams.All += Testers.ContainsExpression(
-            'uuid: POST',
-            "Verify the HTTP server received the POST request.")
+            'uuid: POST', "Verify the HTTP server received the POST request.")
         self.server_https.Streams.All += Testers.ContainsExpression(
-            'uuid: POST',
-            "Verify the HTTPS server received the POST request.")
+            'uuid: POST', "Verify the HTTPS server received the POST request.")
 
         # Same with PUT
-        self.server_http.Streams.All += Testers.ContainsExpression(
-            'uuid: PUT',
-            "Verify the HTTP server received the PUT request.")
+        self.server_http.Streams.All += Testers.ContainsExpression('uuid: PUT', "Verify the HTTP server received the PUT request.")
         self.server_https.Streams.All += Testers.ContainsExpression(
-            'uuid: PUT',
-            "Verify the HTTPS server received the PUT request.")
+            'uuid: PUT', "Verify the HTTPS server received the PUT request.")
 
 
 class MultiplexerSkipPostTest(MultiplexerTestBase):
@@ -192,10 +161,7 @@ class MultiplexerSkipPostTest(MultiplexerTestBase):
     multiplexed_host_replay_file = os.path.join("replays", "multiplexer_copy_skip_post.replay.yaml")
 
     def __init__(self):
-        super().__init__(
-            MultiplexerSkipPostTest.replay_file,
-            MultiplexerSkipPostTest.multiplexed_host_replay_file,
-            skip_post=True)
+        super().__init__(MultiplexerSkipPostTest.replay_file, MultiplexerSkipPostTest.multiplexed_host_replay_file, skip_post=True)
 
     def setupServers(self):
         super().setupServers()
@@ -203,19 +169,15 @@ class MultiplexerSkipPostTest(MultiplexerTestBase):
         # Neither of the multiplexed hosts should receive the POST because skip_post
         # is enabled.
         self.server_http.Streams.All += Testers.ExcludesExpression(
-            'uuid: POST',
-            "Verify the HTTP server did not receive the POST request.")
+            'uuid: POST', "Verify the HTTP server did not receive the POST request.")
         self.server_https.Streams.All += Testers.ExcludesExpression(
-            'uuid: POST',
-            "Verify the HTTPS server did not receive the POST request.")
+            'uuid: POST', "Verify the HTTPS server did not receive the POST request.")
 
         # Same with PUT.
         self.server_http.Streams.All += Testers.ExcludesExpression(
-            'uuid: PUT',
-            "Verify the HTTP server did not receive the PUT request.")
+            'uuid: PUT', "Verify the HTTP server did not receive the PUT request.")
         self.server_https.Streams.All += Testers.ExcludesExpression(
-            'uuid: PUT',
-            "Verify the HTTPS server did not receive the PUT request.")
+            'uuid: PUT', "Verify the HTTPS server did not receive the PUT request.")
 
 
 MultiplexerTest().run()
