@@ -27,15 +27,14 @@ def to_httpdate(dt):
     # string representation of a date according to RFC 1123 (HTTP/1.1).
     weekday = ["Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"][dt.weekday()]
     month = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"][dt.month - 1]
-    return "%s, %02d %s %04d %02d:%02d:%02d GMT" % (weekday, dt.day, month,
-                                                    dt.year, dt.hour, dt.minute, dt.second)
+    return "%s, %02d %s %04d %02d:%02d:%02d GMT" % (weekday, dt.day, month, dt.year, dt.hour, dt.minute, dt.second)
+
 
 # Test description:
 # Preload the cache with the entire asset to be range requested.
 # Reload remap rule with slice plugin
 # Request content through the slice plugin
 
-
 Test.SkipUnless(
     Condition.PluginExists('slice.so'),
     Condition.PluginExists('cache_range_requests.so'),
@@ -50,118 +49,92 @@ server = Test.MakeOriginServer("server", lookup_key="{%uuid}")
 ts = Test.MakeATSProcess("ts", command="traffic_server")
 
 # default root
-req_header_chk = {"headers":
-                  "GET / HTTP/1.1\r\n" +
-                  "Host: www.example.com\r\n" +
-                  "uuid: none\r\n" +
-                  "\r\n",
-                  "timestamp": "1469733493.993",
-                  "body": "",
-                  }
+req_header_chk = {
+    "headers": "GET / HTTP/1.1\r\n" + "Host: www.example.com\r\n" + "uuid: none\r\n" + "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "",
+}
 
-res_header_chk = {"headers":
-                  "HTTP/1.1 200 OK\r\n" +
-                  "Connection: close\r\n" +
-                  "\r\n",
-                  "timestamp": "1469733493.993",
-                  "body": "",
-                  }
+res_header_chk = {
+    "headers": "HTTP/1.1 200 OK\r\n" + "Connection: close\r\n" + "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "",
+}
 
 server.addResponse("sessionlog.json", req_header_chk, res_header_chk)
 
 # set up slice plugin with remap host into cache_range_requests
-ts.Disk.remap_config.AddLines([
-    f'map http://slice/ http://127.0.0.1:{server.Variables.Port}/' +
-    ' @plugin=slice.so @pparam=--blockbytes-test=3 @pparam=--remap-host=crr',
-    f'map http://crr/ http://127.0.0.1:{server.Variables.Port}/' +
-    '  @plugin=cache_range_requests.so @pparam=--consider-ims',
-    f'map http://slicehdr/ http://127.0.0.1:{server.Variables.Port}/' +
-    ' @plugin=slice.so @pparam=--blockbytes-test=3' +
-    ' @pparam=--remap-host=crrhdr @pparam=--crr-ims-header=crr-foo',
-    f'map http://crrhdr/ http://127.0.0.1:{server.Variables.Port}/'
-    '  @plugin=cache_range_requests.so @pparam=--ims-header=crr-foo',
-])
+ts.Disk.remap_config.AddLines(
+    [
+        f'map http://slice/ http://127.0.0.1:{server.Variables.Port}/' +
+        ' @plugin=slice.so @pparam=--blockbytes-test=3 @pparam=--remap-host=crr',
+        f'map http://crr/ http://127.0.0.1:{server.Variables.Port}/' + '  @plugin=cache_range_requests.so @pparam=--consider-ims',
+        f'map http://slicehdr/ http://127.0.0.1:{server.Variables.Port}/' + ' @plugin=slice.so @pparam=--blockbytes-test=3' +
+        ' @pparam=--remap-host=crrhdr @pparam=--crr-ims-header=crr-foo',
+        f'map http://crrhdr/ http://127.0.0.1:{server.Variables.Port}/'
+        '  @plugin=cache_range_requests.so @pparam=--ims-header=crr-foo',
+    ])
 
 ts.Disk.plugin_config.AddLine('xdebug.so')
 
-ts.Disk.records_config.update({
-    'proxy.config.diags.debug.enabled': 0,
-    'proxy.config.diags.debug.tags': 'cache_range_requests|slice',
-})
+ts.Disk.records_config.update(
+    {
+        'proxy.config.diags.debug.enabled': 0,
+        'proxy.config.diags.debug.tags': 'cache_range_requests|slice',
+    })
 
 curl_and_args = 'curl -s -D /dev/stdout -o /dev/stderr -x localhost:{}'.format(ts.Variables.port) + ' -H "x-debug: x-cache"'
 
 # Test case: 2nd slice out of date (refetch and continue)
 
-req_header_2ndold1 = {"headers":
-                      "GET /second HTTP/1.1\r\n" +
-                      "Host: www.example.com\r\n" +
-                      "uuid: etagold-1\r\n" +
-                      "Range: bytes=3-5\r\n"
-                      "\r\n",
-                      "timestamp": "1469733493.993",
-                      "body": "",
-                      }
+req_header_2ndold1 = {
+    "headers": "GET /second HTTP/1.1\r\n" + "Host: www.example.com\r\n" + "uuid: etagold-1\r\n" + "Range: bytes=3-5\r\n"
+               "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "",
+}
 
-res_header_2ndold1 = {"headers":
-                      "HTTP/1.1 206 Partial Content\r\n" +
-                      "Accept-Ranges: bytes\r\n" +
-                      "Cache-Control: max-age=5000\r\n" +
-                      "Connection: close\r\n" +
-                      "Content-Range: bytes 3-4/5\r\n" +
-                      'Etag: "etagold"\r\n' +
-                      "\r\n",
-                      "timestamp": "1469733493.993",
-                      "body": "aa"
-                      }
+res_header_2ndold1 = {
+    "headers":
+        "HTTP/1.1 206 Partial Content\r\n" + "Accept-Ranges: bytes\r\n" + "Cache-Control: max-age=5000\r\n" +
+        "Connection: close\r\n" + "Content-Range: bytes 3-4/5\r\n" + 'Etag: "etagold"\r\n' + "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "aa"
+}
 
 server.addResponse("sessionlog.json", req_header_2ndold1, res_header_2ndold1)
 
-req_header_2ndnew0 = {"headers":
-                      "GET /second HTTP/1.1\r\n" +
-                      "Host: www.example.com\r\n" +
-                      "uuid: etagnew-0\r\n" +
-                      "Range: bytes=0-2\r\n"
-                      "\r\n",
-                      "timestamp": "1469733493.993",
-                      "body": "",
-                      }
+req_header_2ndnew0 = {
+    "headers": "GET /second HTTP/1.1\r\n" + "Host: www.example.com\r\n" + "uuid: etagnew-0\r\n" + "Range: bytes=0-2\r\n"
+               "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "",
+}
 
-res_header_2ndnew0 = {"headers":
-                      "HTTP/1.1 206 Partial Content\r\n" +
-                      "Accept-Ranges: bytes\r\n" +
-                      "Cache-Control: max-age=5000\r\n" +
-                      "Connection: close\r\n" +
-                      "Content-Range: bytes 0-2/5\r\n" +
-                      'Etag: "etagnew"\r\n' +
-                      "\r\n",
-                      "timestamp": "1469733493.993",
-                      "body": "bbb"
-                      }
+res_header_2ndnew0 = {
+    "headers":
+        "HTTP/1.1 206 Partial Content\r\n" + "Accept-Ranges: bytes\r\n" + "Cache-Control: max-age=5000\r\n" +
+        "Connection: close\r\n" + "Content-Range: bytes 0-2/5\r\n" + 'Etag: "etagnew"\r\n' + "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "bbb"
+}
 
 server.addResponse("sessionlog.json", req_header_2ndnew0, res_header_2ndnew0)
 
-req_header_2ndnew1 = {"headers":
-                      "GET /second HTTP/1.1\r\n" +
-                      "Host: www.example.com\r\n" +
-                      "uuid: etagnew-1\r\n" +
-                      "Range: bytes=3-5\r\n"
-                      "\r\n",
-                      "timestamp": "1469733493.993",
-                      "body": "",
-                      }
+req_header_2ndnew1 = {
+    "headers": "GET /second HTTP/1.1\r\n" + "Host: www.example.com\r\n" + "uuid: etagnew-1\r\n" + "Range: bytes=3-5\r\n"
+               "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "",
+}
 
-res_header_2ndnew1 = {"headers":
-                      "HTTP/1.1 206 Partial Content\r\n" +
-                      "Accept-Ranges: bytes\r\n" +
-                      "Cache-Control: max-age=5000\r\n" +
-                      "Connection: close\r\n" +
-                      "Content-Range: bytes 3-4/5\r\n" +
-                      'Etag: "etagnew"\r\n' +
-                      "\r\n",
-                      "timestamp": "1469733493.993",
-                      "body": "bb"
-                      }
+res_header_2ndnew1 = {
+    "headers":
+        "HTTP/1.1 206 Partial Content\r\n" + "Accept-Ranges: bytes\r\n" + "Cache-Control: max-age=5000\r\n" +
+        "Connection: close\r\n" + "Content-Range: bytes 3-4/5\r\n" + 'Etag: "etagnew"\r\n' + "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "bb"
+}
 
 server.addResponse("sessionlog.json", req_header_2ndnew1, res_header_2ndnew1)
 
@@ -205,75 +178,54 @@ tr.StillRunningAfter = ts
 
 # Test case: reference slice out of date (abort connection, heal reference)
 
-req_header_refold0 = {"headers":
-                      "GET /reference HTTP/1.1\r\n" +
-                      "Host: www.example.com\r\n" +
-                      "uuid: etagold-0\r\n" +
-                      "Range: bytes=0-2\r\n"
-                      "\r\n",
-                      "timestamp": "1469733493.993",
-                      "body": "",
-                      }
+req_header_refold0 = {
+    "headers": "GET /reference HTTP/1.1\r\n" + "Host: www.example.com\r\n" + "uuid: etagold-0\r\n" + "Range: bytes=0-2\r\n"
+               "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "",
+}
 
-res_header_refold0 = {"headers":
-                      "HTTP/1.1 206 Partial Content\r\n" +
-                      "Accept-Ranges: bytes\r\n" +
-                      "Cache-Control: max-age=5000\r\n" +
-                      "Connection: close\r\n" +
-                      "Content-Range: bytes 0-2/5\r\n" +
-                      'Etag: "etagold"\r\n' +
-                      "\r\n",
-                      "timestamp": "1469733493.993",
-                      "body": "aaa"
-                      }
+res_header_refold0 = {
+    "headers":
+        "HTTP/1.1 206 Partial Content\r\n" + "Accept-Ranges: bytes\r\n" + "Cache-Control: max-age=5000\r\n" +
+        "Connection: close\r\n" + "Content-Range: bytes 0-2/5\r\n" + 'Etag: "etagold"\r\n' + "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "aaa"
+}
 
 server.addResponse("sessionlog.json", req_header_refold0, res_header_refold0)
 
-req_header_refnew0 = {"headers":
-                      "GET /reference HTTP/1.1\r\n" +
-                      "Host: www.example.com\r\n" +
-                      "uuid: etagnew-0\r\n" +
-                      "Range: bytes=0-2\r\n"
-                      "\r\n",
-                      "timestamp": "1469733493.993",
-                      "body": "",
-                      }
+req_header_refnew0 = {
+    "headers": "GET /reference HTTP/1.1\r\n" + "Host: www.example.com\r\n" + "uuid: etagnew-0\r\n" + "Range: bytes=0-2\r\n"
+               "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "",
+}
 
-res_header_refnew0 = {"headers":
-                      "HTTP/1.1 206 Partial Content\r\n" +
-                      "Accept-Ranges: bytes\r\n" +
-                      "Cache-Control: max-age=5000\r\n" +
-                      "Connection: close\r\n" +
-                      "Content-Range: bytes 0-2/5\r\n" +
-                      'Etag: "etagnew"\r\n' +
-                      "\r\n",
-                      "timestamp": "1469733493.993",
-                      "body": "bbb"
-                      }
+res_header_refnew0 = {
+    "headers":
+        "HTTP/1.1 206 Partial Content\r\n" + "Accept-Ranges: bytes\r\n" + "Cache-Control: max-age=5000\r\n" +
+        "Connection: close\r\n" + "Content-Range: bytes 0-2/5\r\n" + 'Etag: "etagnew"\r\n' + "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "bbb"
+}
 
 server.addResponse("sessionlog.json", req_header_refnew0, res_header_refnew0)
 
-req_header_refnew1 = {"headers":
-                      "GET /reference HTTP/1.1\r\n" +
-                      "Host: www.example.com\r\n" +
-                      "uuid: etagnew-1\r\n" +
-                      "Range: bytes=3-5\r\n"
-                      "\r\n",
-                      "timestamp": "1469733493.993",
-                      "body": "",
-                      }
+req_header_refnew1 = {
+    "headers": "GET /reference HTTP/1.1\r\n" + "Host: www.example.com\r\n" + "uuid: etagnew-1\r\n" + "Range: bytes=3-5\r\n"
+               "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "",
+}
 
-res_header_refnew1 = {"headers":
-                      "HTTP/1.1 206 Partial Content\r\n" +
-                      "Accept-Ranges: bytes\r\n" +
-                      "Cache-Control: max-age=5000\r\n" +
-                      "Connection: close\r\n" +
-                      "Content-Range: bytes 3-4/5\r\n" +
-                      'Etag: "etagnew"\r\n' +
-                      "\r\n",
-                      "timestamp": "1469733493.993",
-                      "body": "bb"
-                      }
+res_header_refnew1 = {
+    "headers":
+        "HTTP/1.1 206 Partial Content\r\n" + "Accept-Ranges: bytes\r\n" + "Cache-Control: max-age=5000\r\n" +
+        "Connection: close\r\n" + "Content-Range: bytes 3-4/5\r\n" + 'Etag: "etagnew"\r\n' + "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "bb"
+}
 
 server.addResponse("sessionlog.json", req_header_refnew1, res_header_refnew1)
 
@@ -317,25 +269,18 @@ tr.StillRunningAfter = ts
 
 # Request results in 200, not 206 (server not support range requests)
 
-req_header_200 = {"headers":
-                  "GET /code200 HTTP/1.1\r\n" +
-                  "Host: www.example.com\r\n" +
-                  "uuid: code200\r\n" +
-                  "Range: bytes=3-5\r\n"
-                  "\r\n",
-                  "timestamp": "1469733493.993",
-                  "body": "",
-                  }
+req_header_200 = {
+    "headers": "GET /code200 HTTP/1.1\r\n" + "Host: www.example.com\r\n" + "uuid: code200\r\n" + "Range: bytes=3-5\r\n"
+               "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "",
+}
 
-res_header_200 = {"headers":
-                  "HTTP/1.1 200 OK\r\n" +
-                  "Cache-Control: max-age=5000\r\n" +
-                  "Connection: close\r\n" +
-                  'Etag: "etag"\r\n' +
-                  "\r\n",
-                  "timestamp": "1469733493.993",
-                  "body": "ccccc"
-                  }
+res_header_200 = {
+    "headers": "HTTP/1.1 200 OK\r\n" + "Cache-Control: max-age=5000\r\n" + "Connection: close\r\n" + 'Etag: "etag"\r\n' + "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "ccccc"
+}
 
 server.addResponse("sessionlog.json", req_header_200, res_header_200)
 
@@ -351,27 +296,20 @@ tr.StillRunningAfter = ts
 # Test for asset gone
 
 # Preload
-req_header_assetgone0 = {"headers":
-                         "GET /assetgone HTTP/1.1\r\n" +
-                         "Host: www.example.com\r\n" +
-                         "uuid: assetgone-0\r\n" +
-                         "Range: bytes=0-2\r\n"
-                         "\r\n",
-                         "timestamp": "1469733493.993",
-                         "body": "",
-                         }
+req_header_assetgone0 = {
+    "headers": "GET /assetgone HTTP/1.1\r\n" + "Host: www.example.com\r\n" + "uuid: assetgone-0\r\n" + "Range: bytes=0-2\r\n"
+               "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "",
+}
 
-res_header_assetgone0 = {"headers":
-                         "HTTP/1.1 206 Partial Content\r\n" +
-                         "Accept-Ranges: bytes\r\n" +
-                         "Cache-Control: max-age=5000\r\n" +
-                         "Connection: close\r\n" +
-                         "Content-Range: bytes 0-2/5\r\n" +
-                         'Etag: "etag"\r\n' +
-                         "\r\n",
-                         "timestamp": "1469733493.993",
-                         "body": "aaa"
-                         }
+res_header_assetgone0 = {
+    "headers":
+        "HTTP/1.1 206 Partial Content\r\n" + "Accept-Ranges: bytes\r\n" + "Cache-Control: max-age=5000\r\n" +
+        "Connection: close\r\n" + "Content-Range: bytes 0-2/5\r\n" + 'Etag: "etag"\r\n' + "\r\n",
+    "timestamp": "1469733493.993",
+    "body": "aaa"
+}
 
 server.addResponse("sessionlog.json", req_header_assetgone0, res_header_assetgone0)
 
