@@ -50,5 +50,5 @@ tr.ChownForATSProcess(trafficserver_dir)
 p = tr.Processes.Default
 p.Command = "$ATS_BIN/traffic_manager --run-root=" + rr_file
 p.RunningEvent.Connect(Testers.Lambda(lambda ev: StopProcess(ev, 10)))
-p.Streams.All = Testers.ContainsExpression("traffic_server: using root directory '" +
-                                           runroot_path + "'", "check if the right runroot is passed down")
+p.Streams.All = Testers.ContainsExpression(
+    "traffic_server: using root directory '" + runroot_path + "'", "check if the right runroot is passed down")
