@@ -17,9 +17,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from http_utils import (wait_for_headers_complete,
-                        determine_outstanding_bytes_to_read,
-                        drain_socket)
+from http_utils import (wait_for_headers_complete, determine_outstanding_bytes_to_read, drain_socket)
 
 import argparse
 import socket
@@ -29,24 +27,15 @@ import sys
 def parse_args() -> argparse.Namespace:
     """Parse the command line arguments."""
     parser = argparse.ArgumentParser()
+    parser.add_argument("proxy_address", help="Address of the proxy to connect to.")
+    parser.add_argument("proxy_port", type=int, help="The port of the proxy to connect to.")
     parser.add_argument(
-        "proxy_address",
-        help="Address of the proxy to connect to.")
-    parser.add_argument(
-        "proxy_port",
-        type=int,
-        help="The port of the proxy to connect to.")
-    parser.add_argument(
-        '-s', '--server-hostname',
+        '-s',
+        '--server-hostname',
         dest="server_hostname",
         default="some.server.com",
         help="The hostname of the server to connect to.")
-    parser.add_argument(
-        "-t", "--send_time",
-        dest="send_time",
-        type=int,
-        default=3,
-        help="The number of seconds to send the POST.")
+    parser.add_argument("-t", "--send_time", dest="send_time", type=int, default=3, help="The number of seconds to send the POST.")
     parser.add_argument(
         '--finish-request',
         dest="finish_request",
@@ -69,11 +58,7 @@ def open_connection(address: str, port: int) -> socket.socket:
     return sock
 
 
-def send_slow_post(
-        sock: socket.socket,
-        server_hostname: str,
-        send_time: int,
-        finish_request: bool) -> None:
+def send_slow_post(sock: socket.socket, server_hostname: str, send_time: int, finish_request: bool) -> None:
     """Send a slow POST request.
 
     :param sock: The socket to send the request on.
@@ -84,11 +69,8 @@ def send_slow_post(
     """
     # Send the POST request.
     host_header = f'Host: {server_hostname}\r\n'.encode()
-    request = (
-        b"POST / HTTP/1.1\r\n"
-        + host_header +
-        b"Transfer-Encoding: chunked\r\n"
-        b"\r\n")
+    request = (b"POST / HTTP/1.1\r\n" + host_header + b"Transfer-Encoding: chunked\r\n"
+               b"\r\n")
     sock.sendall(request)
     print('Sent request headers:')
     print(request.decode())
@@ -128,11 +110,7 @@ def main() -> int:
     print(args)
 
     with open_connection(args.proxy_address, args.proxy_port) as sock:
-        send_slow_post(
-            sock,
-            args.server_hostname,
-            args.send_time,
-            args.finish_request)
+        send_slow_post(sock, args.server_hostname, args.send_time, args.finish_request)
 
         if args.finish_request:
             drain_response(sock)
