@@ -24,18 +24,24 @@ Test conf_remp to specify different client certificates to offer to the origin
 ts = Test.MakeATSProcess("ts", command="traffic_manager", select_ports=True)
 cafile = "{0}/signer.pem".format(Test.RunDirectory)
 cafile2 = "{0}/signer2.pem".format(Test.RunDirectory)
-server = Test.MakeOriginServer("server",
-                               ssl=True,
-                               options={"--clientCA": cafile,
-                                        "--clientverify": ""},
-                               clientcert="{0}/signed-foo.pem".format(Test.RunDirectory),
-                               clientkey="{0}/signed-foo.key".format(Test.RunDirectory))
-server2 = Test.MakeOriginServer("server2",
-                                ssl=True,
-                                options={"--clientCA": cafile2,
-                                         "--clientverify": ""},
-                                clientcert="{0}/signed2-bar.pem".format(Test.RunDirectory),
-                                clientkey="{0}/signed-bar.key".format(Test.RunDirectory))
+server = Test.MakeOriginServer(
+    "server",
+    ssl=True,
+    options={
+        "--clientCA": cafile,
+        "--clientverify": ""
+    },
+    clientcert="{0}/signed-foo.pem".format(Test.RunDirectory),
+    clientkey="{0}/signed-foo.key".format(Test.RunDirectory))
+server2 = Test.MakeOriginServer(
+    "server2",
+    ssl=True,
+    options={
+        "--clientCA": cafile2,
+        "--clientverify": ""
+    },
+    clientcert="{0}/signed2-bar.pem".format(Test.RunDirectory),
+    clientkey="{0}/signed-bar.key".format(Test.RunDirectory))
 server.Setup.Copy("ssl/signer.pem")
 server.Setup.Copy("ssl/signer2.pem")
 server.Setup.Copy("ssl/signed-foo.pem")
@@ -67,44 +73,35 @@ ts.addSSLfile("ssl/signed-bar.pem")
 ts.addSSLfile("ssl/signed2-bar.pem")
 ts.addSSLfile("ssl/signed-bar.key")
 
-ts.Disk.records_config.update({
-    'proxy.config.diags.debug.enabled': 1,
-    'proxy.config.diags.debug.tags': 'ssl',
-    'proxy.config.ssl.server.cert.path': '{0}'.format(ts.Variables.SSLDir),
-    'proxy.config.ssl.server.private_key.path': '{0}'.format(ts.Variables.SSLDir),
-    'proxy.config.ssl.client.cert.path': '{0}'.format(ts.Variables.SSLDir),
-    'proxy.config.ssl.client.cert.filename': 'signed-foo.pem',
-    'proxy.config.ssl.client.private_key.path': '{0}'.format(ts.Variables.SSLDir),
-    'proxy.config.ssl.client.private_key.filename': 'signed-foo.key',
-    'proxy.config.exec_thread.autoconfig.scale': 1.0,
-    'proxy.config.url_remap.pristine_host_hdr': 1,
-    'proxy.config.ssl.client.verify.server.policy': 'PERMISSIVE',
-})
+ts.Disk.records_config.update(
+    {
+        'proxy.config.diags.debug.enabled': 1,
+        'proxy.config.diags.debug.tags': 'ssl',
+        'proxy.config.ssl.server.cert.path': '{0}'.format(ts.Variables.SSLDir),
+        'proxy.config.ssl.server.private_key.path': '{0}'.format(ts.Variables.SSLDir),
+        'proxy.config.ssl.client.cert.path': '{0}'.format(ts.Variables.SSLDir),
+        'proxy.config.ssl.client.cert.filename': 'signed-foo.pem',
+        'proxy.config.ssl.client.private_key.path': '{0}'.format(ts.Variables.SSLDir),
+        'proxy.config.ssl.client.private_key.filename': 'signed-foo.key',
+        'proxy.config.exec_thread.autoconfig.scale': 1.0,
+        'proxy.config.url_remap.pristine_host_hdr': 1,
+        'proxy.config.ssl.client.verify.server.policy': 'PERMISSIVE',
+    })
 
-ts.Disk.ssl_multicert_config.AddLine(
-    'dest_ip=* ssl_cert_name=server.pem ssl_key_name=server.key'
-)
+ts.Disk.ssl_multicert_config.AddLine('dest_ip=* ssl_cert_name=server.pem ssl_key_name=server.key')
 
 ts.Disk.remap_config.AddLine(
-    'map /case1 https://127.0.0.1:{0}/ @plugin=conf_remap.so @pparam=proxy.config.ssl.client.cert.filename={1} plugin=conf_remap.so @pparam=proxy.config.ssl.client.private_key.filename={2}'.format(
-        server.Variables.SSL_Port,
-        "signed-foo.pem",
-        "signed-foo.key"))
+    'map /case1 https://127.0.0.1:{0}/ @plugin=conf_remap.so @pparam=proxy.config.ssl.client.cert.filename={1} plugin=conf_remap.so @pparam=proxy.config.ssl.client.private_key.filename={2}'
+    .format(server.Variables.SSL_Port, "signed-foo.pem", "signed-foo.key"))
 ts.Disk.remap_config.AddLine(
-    'map /badcase1 https://127.0.0.1:{0}/ @plugin=conf_remap.so @pparam=proxy.config.ssl.client.cert.filename={1} plugin=conf_remap.so @pparam=proxy.config.ssl.client.private_key.filename={2}'.format(
-        server.Variables.SSL_Port,
-        "signed2-foo.pem",
-        "signed-foo.key"))
+    'map /badcase1 https://127.0.0.1:{0}/ @plugin=conf_remap.so @pparam=proxy.config.ssl.client.cert.filename={1} plugin=conf_remap.so @pparam=proxy.config.ssl.client.private_key.filename={2}'
+    .format(server.Variables.SSL_Port, "signed2-foo.pem", "signed-foo.key"))
 ts.Disk.remap_config.AddLine(
-    'map /case2 https://127.0.0.1:{0}/ @plugin=conf_remap.so @pparam=proxy.config.ssl.client.cert.filename={1} plugin=conf_remap.so @pparam=proxy.config.ssl.client.private_key.filename={2}'.format(
-        server2.Variables.SSL_Port,
-        "signed2-foo.pem",
-        "signed-foo.key"))
+    'map /case2 https://127.0.0.1:{0}/ @plugin=conf_remap.so @pparam=proxy.config.ssl.client.cert.filename={1} plugin=conf_remap.so @pparam=proxy.config.ssl.client.private_key.filename={2}'
+    .format(server2.Variables.SSL_Port, "signed2-foo.pem", "signed-foo.key"))
 ts.Disk.remap_config.AddLine(
-    'map /badcase2 https://127.0.0.1:{0}/ @plugin=conf_remap.so @pparam=proxy.config.ssl.client.cert.filename={1} plugin=conf_remap.so @pparam=proxy.config.ssl.client.private_key.filename={2}'.format(
-        server2.Variables.SSL_Port,
-        "signed-foo.pem",
-        "signed-foo.key"))
+    'map /badcase2 https://127.0.0.1:{0}/ @plugin=conf_remap.so @pparam=proxy.config.ssl.client.cert.filename={1} plugin=conf_remap.so @pparam=proxy.config.ssl.client.private_key.filename={2}'
+    .format(server2.Variables.SSL_Port, "signed-foo.pem", "signed-foo.key"))
 
 # Should succeed
 tr = Test.AddTestRun("Connect with correct client cert to first server")
