@@ -23,9 +23,7 @@ Test TLS protocol offering  based on SNI
 # By default only offer TLSv1_2
 # for special domain foo.com only offer TLSv1 and TLSv1_1
 
-Test.SkipUnless(
-    Condition.HasOpenSSLVersion("1.1.1")
-)
+Test.SkipUnless(Condition.HasOpenSSLVersion("1.1.1"))
 
 # Define default ATS
 ts = Test.MakeATSProcess("ts", select_ports=True, enable_tls=True)
@@ -42,25 +40,24 @@ ts.addSSLfile("ssl/server.key")
 # Need no remap rules.  Everything should be processed by sni
 
 # Make sure the TS server certs are different from the origin certs
-ts.Disk.ssl_multicert_config.AddLine(
-    'dest_ip=* ssl_cert_name=server.pem ssl_key_name=server.key'
-)
+ts.Disk.ssl_multicert_config.AddLine('dest_ip=* ssl_cert_name=server.pem ssl_key_name=server.key')
 
 cipher_suite = 'ECDHE-RSA-AES128-GCM-SHA256:ECDHE-RSA-AES256-GCM-SHA384:ECDHE-RSA-AES128-SHA256:ECDHE-RSA-AES256-SHA384:AES128-GCM-SHA256:AES256-GCM-SHA384:ECDHE-RSA-RC4-SHA:ECDHE-RSA-AES128-SHA:ECDHE-RSA-AES256-SHA:RC4-SHA:RC4-MD5:AES128-SHA:AES256-SHA:DES-CBC3-SHA!SRP:!DSS:!PSK:!aNULL:!eNULL:!SSLv2'
 if Condition.HasOpenSSLVersion("3.0.0"):
     cipher_suite += ":@SECLEVEL=0"
 
-ts.Disk.records_config.update({
-    'proxy.config.ssl.server.cert.path': '{0}'.format(ts.Variables.SSLDir),
-    'proxy.config.ssl.server.private_key.path': '{0}'.format(ts.Variables.SSLDir),
-    'proxy.config.ssl.server.cipher_suite': cipher_suite,
-    'proxy.config.ssl.client.CA.cert.path': '{0}'.format(ts.Variables.SSLDir),
-    'proxy.config.url_remap.pristine_host_hdr': 1,
-    'proxy.config.ssl.TLSv1': 0,
-    'proxy.config.ssl.TLSv1_1': 0,
-    'proxy.config.exec_thread.autoconfig.scale': 1.0,
-    'proxy.config.ssl.TLSv1_2': 1
-})
+ts.Disk.records_config.update(
+    {
+        'proxy.config.ssl.server.cert.path': '{0}'.format(ts.Variables.SSLDir),
+        'proxy.config.ssl.server.private_key.path': '{0}'.format(ts.Variables.SSLDir),
+        'proxy.config.ssl.server.cipher_suite': cipher_suite,
+        'proxy.config.ssl.client.CA.cert.path': '{0}'.format(ts.Variables.SSLDir),
+        'proxy.config.url_remap.pristine_host_hdr': 1,
+        'proxy.config.ssl.TLSv1': 0,
+        'proxy.config.ssl.TLSv1_1': 0,
+        'proxy.config.exec_thread.autoconfig.scale': 1.0,
+        'proxy.config.ssl.TLSv1_2': 1
+    })
 
 # foo.com should only offer the older TLS protocols
 # bar.com should terminate.
@@ -68,7 +65,7 @@ ts.Disk.records_config.update({
 ts.Disk.sni_yaml.AddLines([
     'sni:',
     '- fqdn: foo.com',
-    '  valid_tls_versions_in: [ TLSv1, TLSv1_1 ]'
+    '  valid_tls_versions_in: [ TLSv1, TLSv1_1 ]',
 ])
 
 # Target foo.com for TLSv1_2.  Should fail
