@@ -22,14 +22,20 @@ Test tls server  certificate verification options. Exercise conf_remap for ca bu
 
 # Define default ATS
 ts = Test.MakeATSProcess("ts", select_ports=True)
-server1 = Test.MakeOriginServer("server1",
-                                ssl=True,
-                                options={"--key": "{0}/signed-foo.key".format(Test.RunDirectory),
-                                         "--cert": "{0}/signed-foo.pem".format(Test.RunDirectory)})
-server2 = Test.MakeOriginServer("server2",
-                                ssl=True,
-                                options={"--key": "{0}/signed-foo.key".format(Test.RunDirectory),
-                                         "--cert": "{0}/signed2-foo.pem".format(Test.RunDirectory)})
+server1 = Test.MakeOriginServer(
+    "server1",
+    ssl=True,
+    options={
+        "--key": "{0}/signed-foo.key".format(Test.RunDirectory),
+        "--cert": "{0}/signed-foo.pem".format(Test.RunDirectory)
+    })
+server2 = Test.MakeOriginServer(
+    "server2",
+    ssl=True,
+    options={
+        "--key": "{0}/signed-foo.key".format(Test.RunDirectory),
+        "--cert": "{0}/signed2-foo.pem".format(Test.RunDirectory)
+    })
 
 request_foo_header = {"headers": "GET / HTTP/1.1\r\nHost: foo.com\r\n\r\n", "timestamp": "1469733493.993", "body": ""}
 request_bad_foo_header = {"headers": "GET / HTTP/1.1\r\nHost: bad_foo.com\r\n\r\n", "timestamp": "1469733493.993", "body": ""}
@@ -54,38 +60,33 @@ ts.addSSLfile("ssl/signer2.key")
 
 ts.Disk.remap_config.AddLine(
     'map /case1 https://127.0.0.1:{0}/ @plugin=conf_remap.so @pparam=proxy.config.ssl.client.CA.cert.filename={1}/{2}'.format(
-        server1.Variables.SSL_Port, ts.Variables.SSLDir, "signer.pem")
-)
+        server1.Variables.SSL_Port, ts.Variables.SSLDir, "signer.pem"))
 ts.Disk.remap_config.AddLine(
     'map /badcase1 https://127.0.0.1:{0}/ @plugin=conf_remap.so @pparam=proxy.config.ssl.client.CA.cert.filename={1}/{2}'.format(
-        server1.Variables.SSL_Port, ts.Variables.SSLDir, "signer2.pem")
-)
+        server1.Variables.SSL_Port, ts.Variables.SSLDir, "signer2.pem"))
 ts.Disk.remap_config.AddLine(
     'map /case2 https://127.0.0.1:{0}/ @plugin=conf_remap.so @pparam=proxy.config.ssl.client.CA.cert.filename={1}/{2}'.format(
-        server2.Variables.SSL_Port, ts.Variables.SSLDir, "signer2.pem")
-)
+        server2.Variables.SSL_Port, ts.Variables.SSLDir, "signer2.pem"))
 ts.Disk.remap_config.AddLine(
     'map /badcase2 https://127.0.0.1:{0}/ @plugin=conf_remap.so @pparam=proxy.config.ssl.client.CA.cert.filename={1}/{2}'.format(
-        server2.Variables.SSL_Port, ts.Variables.SSLDir, "signer.pem")
-)
+        server2.Variables.SSL_Port, ts.Variables.SSLDir, "signer.pem"))
 
-ts.Disk.ssl_multicert_config.AddLine(
-    'dest_ip=* ssl_cert_name=server.pem ssl_key_name=server.key'
-)
+ts.Disk.ssl_multicert_config.AddLine('dest_ip=* ssl_cert_name=server.pem ssl_key_name=server.key')
 
 # Case 1, global config policy=permissive properties=signature
 #         override for foo.com policy=enforced properties=all
-ts.Disk.records_config.update({
-    'proxy.config.ssl.server.cert.path': '{0}'.format(ts.Variables.SSLDir),
-    'proxy.config.ssl.server.private_key.path': '{0}'.format(ts.Variables.SSLDir),
-    # set global policy
-    'proxy.config.ssl.client.verify.server.policy': 'ENFORCED',
-    'proxy.config.ssl.client.verify.server.properties': 'SIGNATURE',
-    'proxy.config.ssl.client.CA.cert.path': '/tmp',
-    'proxy.config.ssl.client.CA.cert.filename': '{0}/signer.pem'.format(ts.Variables.SSLDir),
-    'proxy.config.exec_thread.autoconfig.scale': 1.0,
-    'proxy.config.url_remap.pristine_host_hdr': 1
-})
+ts.Disk.records_config.update(
+    {
+        'proxy.config.ssl.server.cert.path': '{0}'.format(ts.Variables.SSLDir),
+        'proxy.config.ssl.server.private_key.path': '{0}'.format(ts.Variables.SSLDir),
+        # set global policy
+        'proxy.config.ssl.client.verify.server.policy': 'ENFORCED',
+        'proxy.config.ssl.client.verify.server.properties': 'SIGNATURE',
+        'proxy.config.ssl.client.CA.cert.path': '/tmp',
+        'proxy.config.ssl.client.CA.cert.filename': '{0}/signer.pem'.format(ts.Variables.SSLDir),
+        'proxy.config.exec_thread.autoconfig.scale': 1.0,
+        'proxy.config.url_remap.pristine_host_hdr': 1
+    })
 
 # Should succeed
 tr = Test.AddTestRun("Use correct ca bundle for server 1")
