@@ -15,6 +15,7 @@
 #  limitations under the License.
 
 import os
+
 Test.Summary = '''
 Test traffic_ctl config reload with remap.config .include directive
 '''
@@ -29,35 +30,26 @@ nameserver = Test.MakeDNServer("dns", default='127.0.0.1')
 
 ts.Disk.File(ts.Variables.CONFIGDIR + "/test.inc", id="test_cfg", typename="ats:config")
 ts.Disk.test_cfg.AddLine(
-    "map http://example.two/ http://yada.com/ " +
-    "@plugin=conf_remap.so @pparam=proxy.config.url_remap.pristine_host_hdr=1"
-)
+    "map http://example.two/ http://yada.com/ " + "@plugin=conf_remap.so @pparam=proxy.config.url_remap.pristine_host_hdr=1")
 
-ts.Disk.remap_config.AddLine(
-    "map http://example.one/ http://yada.com/"
-)
-ts.Disk.remap_config.AddLine(
-    ".include test.inc"
-)
-ts.Disk.remap_config.AddLine(
-    "map http://example.three/ http://yada.com/"
-)
+ts.Disk.remap_config.AddLine("map http://example.one/ http://yada.com/")
+ts.Disk.remap_config.AddLine(".include test.inc")
+ts.Disk.remap_config.AddLine("map http://example.three/ http://yada.com/")
 
 # minimal configuration
-ts.Disk.records_config.update({
-    'proxy.config.diags.debug.enabled': 1,
-    'proxy.config.diags.debug.tags': 'regex_remap|url_rewrite|plugin_factory',
-    'proxy.config.dns.nameservers': f"127.0.0.1:{nameserver.Variables.Port}",
-})
+ts.Disk.records_config.update(
+    {
+        'proxy.config.diags.debug.enabled': 1,
+        'proxy.config.diags.debug.tags': 'regex_remap|url_rewrite|plugin_factory',
+        'proxy.config.dns.nameservers': f"127.0.0.1:{nameserver.Variables.Port}",
+    })
 
 tr = Test.AddTestRun("Start TS, then update test.inc")
 tr.Processes.Default.StartBefore(Test.Processes.ts)
 tr.Processes.Default.StartBefore(nameserver)
 test_inc_path = ts.Variables.CONFIGDIR + "/test.inc"
 tr.Processes.Default.Command = (
-    f"rm -f {test_inc_path} ; " +
-    f"echo 'map http://example.four/ http://localhost/ @plugin=generator.so' > {test_inc_path}"
-)
+    f"rm -f {test_inc_path} ; " + f"echo 'map http://example.four/ http://localhost/ @plugin=generator.so' > {test_inc_path}")
 tr.Processes.Default.ReturnCode = 0
 tr.StillRunningAfter = ts
 
@@ -74,12 +66,9 @@ tr.Processes.Default.ReturnCode = 0
 tr.StillRunningAfter = ts
 
 tr = Test.AddTestRun("Get response from generator")
-tr.Processes.Default.Command = (
-    f'test $$(curl --proxy 127.0.0.1:{ts.Variables.port} http://example.four/nocache/5 | wc -c) == 5'
-)
+tr.Processes.Default.Command = (f'test $$(curl --proxy 127.0.0.1:{ts.Variables.port} http://example.four/nocache/5 | wc -c) == 5')
 tr.Processes.Default.ReturnCode = 0
 tr.StillRunningAfter = ts
 
 ts.Disk.manager_log.Content += Testers.ExcludesExpression(
-    "needs restart",
-    "Ensure that extra msg reported in issue #7530 does not reappear")
+    "needs restart", "Ensure that extra msg reported in issue #7530 does not reappear")
